# encoding: utf-8
# module System.Security.RightsManagement calls itself RightsManagement
# from WindowsBase,Version=4.0.0.0,Culture=neutral,PublicKeyToken=31bf3856ad364e35
# by generator 1.145
""" NamespaceTracker represent a CLS namespace. """
# no imports

# no functions
# classes

class AuthenticationType(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the method of rights management authentication.

 

 enum AuthenticationType,values: Internal (3),Passport (1),Windows (0),WindowsPassport (2)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Internal=None
 Passport=None
 value__=None
 Windows=None
 WindowsPassport=None


class ContentGrant(object):
 """
 Represents a right granted to a user to access information in a rights managed document.

 

 ContentGrant(user: ContentUser,right: ContentRight)

 ContentGrant(user: ContentUser,right: ContentRight,validFrom: DateTime,validUntil: DateTime)
 """
 @staticmethod
 def __new__(self,user,right,validFrom=None,validUntil=None):
  """
  __new__(cls: type,user: ContentUser,right: ContentRight)

  __new__(cls: type,user: ContentUser,right: ContentRight,validFrom: DateTime,validUntil: DateTime)
  """
  pass
 Right=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Security.RightsManagement.ContentRight that is granted.



Get: Right(self: ContentGrant) -> ContentRight



"""

 User=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the user who is granted the access System.Security.RightsManagement.ContentGrant.Right.



Get: User(self: ContentGrant) -> ContentUser



"""

 ValidFrom=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the starting date and time that the granted System.Security.RightsManagement.ContentGrant.Right begins.



Get: ValidFrom(self: ContentGrant) -> DateTime



"""

 ValidUntil=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the ending date and time that the granted System.Security.RightsManagement.ContentGrant.Right expires.



Get: ValidUntil(self: ContentGrant) -> DateTime



"""



class ContentRight(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies rights that can be granted to users for accessing content in a rights managed document.

 

 enum ContentRight,values: DocumentEdit (11),Edit (1),Export (12),Extract (3),Forward (7),ObjectModel (4),Owner (5),Print (2),Reply (8),ReplyAll (9),Sign (10),View (0),ViewRightsData (6)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 DocumentEdit=None
 Edit=None
 Export=None
 Extract=None
 Forward=None
 ObjectModel=None
 Owner=None
 Print=None
 Reply=None
 ReplyAll=None
 Sign=None
 value__=None
 View=None
 ViewRightsData=None


class ContentUser(object):
 """
 Represents a user or user-group for granting access to rights managed content.

 

 ContentUser(name: str,authenticationType: AuthenticationType)
 """
 def Equals(self,obj):
  """
  Equals(self: ContentUser,obj: object) -> bool

  

   Returns a value that indicates whether this System.Security.RightsManagement.ContentUser is 

    equivalent to another given instance.

  

  

   obj: The user instance to compare for equality.

   Returns: true if System.Security.RightsManagement.ContentUser.Name and 

    System.Security.RightsManagement.ContentUser.AuthenticationType are the same for both this user 

    and the given user; otherwise,false.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: ContentUser) -> int

  

   Returns a computed hash code based on the user System.Security.RightsManagement.ContentUser.Name 

    and System.Security.RightsManagement.ContentUser.AuthenticationType.

  

   Returns: A hash code computed from the user System.Security.RightsManagement.ContentUser.Name and 

    System.Security.RightsManagement.ContentUser.AuthenticationType.
  """
  pass
 def IsAuthenticated(self):
  """
  IsAuthenticated(self: ContentUser) -> bool

  

   Returns a value that indicates whether the user is currently authenticated.

   Returns: true if the user is currently authenticated; otherwise,false.  The default is false until 

    authenticated.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 @staticmethod
 def __new__(self,name,authenticationType):
  """ __new__(cls: type,name: str,authenticationType: AuthenticationType) """
  pass
 def __ne__(self,*args):
  pass
 AuthenticationType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Security.RightsManagement.AuthenticationType specified to the System.Security.RightsManagement.ContentUser.#ctor(System.String,System.Security.RightsManagement.AuthenticationType) constructor.



Get: AuthenticationType(self: ContentUser) -> AuthenticationType



"""

 Name=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the user or group name specified to the System.Security.RightsManagement.ContentUser.#ctor(System.String,System.Security.RightsManagement.AuthenticationType) constructor.



Get: Name(self: ContentUser) -> str



"""


 AnyoneUser=None
 OwnerUser=None


class CryptoProvider(object,IDisposable):
 """ Provides digital rights management services for encrypting and decrypting protected content. """
 def Decrypt(self,cryptoText):
  """
  Decrypt(self: CryptoProvider,cryptoText: Array[Byte]) -> Array[Byte]

  

   Decrypts cipher text to clear text.

  

   cryptoText: The cipher text to decrypt.

   Returns: The decrypted clear text of cryptoText.
  """
  pass
 def Dispose(self):
  """
  Dispose(self: CryptoProvider)

   Releases all resources used by the System.Security.RightsManagement.CryptoProvider.
  """
  pass
 def Encrypt(self,clearText):
  """
  Encrypt(self: CryptoProvider,clearText: Array[Byte]) -> Array[Byte]

  

   Encrypts clear text to cipher text.

  

   clearText: The clear text content to encrypt.

   Returns: Encrypted cipher text of the given clearText.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 BlockSize=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the cipher block size,in bytes.



Get: BlockSize(self: CryptoProvider) -> int



"""

 BoundGrants=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a collection listing the rights that passed verification and that are granted to the user.



Get: BoundGrants(self: CryptoProvider) -> ReadOnlyCollection[ContentGrant]



"""

 CanDecrypt=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates whether the user has rights to decrypt.



Get: CanDecrypt(self: CryptoProvider) -> bool



"""

 CanEncrypt=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates whether the user has rights to encrypt.



Get: CanEncrypt(self: CryptoProvider) -> bool



"""

 CanMergeBlocks=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates whether System.Security.RightsManagement.CryptoProvider.Encrypt(System.Byte[]) and System.Security.RightsManagement.CryptoProvider.Decrypt(System.Byte[]) can accept buffers that are different block sizes in length.



Get: CanMergeBlocks(self: CryptoProvider) -> bool



"""



class LocalizedNameDescriptionPair(object):
 """
 Represents an immutable (read-only) pair of "Name" and "Description" strings.

 

 LocalizedNameDescriptionPair(name: str,description: str)
 """
 def Equals(self,obj):
  """
  Equals(self: LocalizedNameDescriptionPair,obj: object) -> bool

  

   Indicates whether the System.Security.RightsManagement.LocalizedNameDescriptionPair.Name and 

    System.Security.RightsManagement.LocalizedNameDescriptionPair.Description properties of a given 

    object match those of this System.Security.RightsManagement.LocalizedNameDescriptionPair.

  

  

   obj: The object to compare the System.Security.RightsManagement.LocalizedNameDescriptionPair.Name and 

    System.Security.RightsManagement.LocalizedNameDescriptionPair.Description properties of.

  

   Returns: true if the System.Security.RightsManagement.LocalizedNameDescriptionPair.Name and 

    System.Security.RightsManagement.LocalizedNameDescriptionPair.Description properties of the 

    given object match those of this instance; otherwise,false.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: LocalizedNameDescriptionPair) -> int

  

   Gets a computed hash code based on the 

    System.Security.RightsManagement.LocalizedNameDescriptionPair.Name and 

    System.Security.RightsManagement.LocalizedNameDescriptionPair.Description properties.

  

   Returns: A computed hash code based on the 

    System.Security.RightsManagement.LocalizedNameDescriptionPair.Name and 

    System.Security.RightsManagement.LocalizedNameDescriptionPair.Description properties of this 

    System.Security.RightsManagement.LocalizedNameDescriptionPair.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 @staticmethod
 def __new__(self,name,description):
  """ __new__(cls: type,name: str,description: str) """
  pass
 def __ne__(self,*args):
  pass
 Description=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the locale description.



Get: Description(self: LocalizedNameDescriptionPair) -> str



"""

 Name=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the locale name.



Get: Name(self: LocalizedNameDescriptionPair) -> str



"""



class PublishLicense(object):
 """
 Represents a signed rights managed publish license.

 

 PublishLicense(signedPublishLicense: str)
 """
 def AcquireUseLicense(self,secureEnvironment):
  """
  AcquireUseLicense(self: PublishLicense,secureEnvironment: SecureEnvironment) -> UseLicense

  

   Attempts to acquire a System.Security.RightsManagement.UseLicense for a user or user group in a 

    specified System.Security.RightsManagement.SecureEnvironment.

  

  

   secureEnvironment: The secure environment for license activation and binding.

   Returns: The System.Security.RightsManagement.UseLicense for a user or user group in the specified 

    secureEnvironment.
  """
  pass
 def AcquireUseLicenseNoUI(self,secureEnvironment):
  """
  AcquireUseLicenseNoUI(self: PublishLicense,secureEnvironment: SecureEnvironment) -> UseLicense

  

   Attempts to acquire a System.Security.RightsManagement.UseLicense for a user or user group in a 

    specified System.Security.RightsManagement.SecureEnvironment.

  

  

   secureEnvironment: The secure environment for license activation and binding.

   Returns: The System.Security.RightsManagement.UseLicense for a user or user group in the specified 

    secureEnvironment.
  """
  pass
 def DecryptUnsignedPublishLicense(self,cryptoProvider):
  """
  DecryptUnsignedPublishLicense(self: PublishLicense,cryptoProvider: CryptoProvider) -> UnsignedPublishLicense

  

   Returns a decrypted System.Security.RightsManagement.UnsignedPublishLicense version of this 

    signed System.Security.RightsManagement.PublishLicense.

  

  

   cryptoProvider: The rights management service to use for decrypting the license.

   Returns: A decrypted,unsigned version of this license.
  """
  pass
 def ToString(self):
  """
  ToString(self: PublishLicense) -> str

  

   Returns the serialized XrML�string that was�used to create this license.

   Returns: The serialized�Extensible Rights Markup Language (XrML) string that was�used to create this 

    license.
  """
  pass
 @staticmethod
 def __new__(self,signedPublishLicense):
  """ __new__(cls: type,signedPublishLicense: str) """
  pass
 ContentId=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the publisher-created content identifier.



Get: ContentId(self: PublishLicense) -> Guid



"""

 ReferralInfoName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the contact name for the author or publisher of the content.



Get: ReferralInfoName(self: PublishLicense) -> str



"""

 ReferralInfoUri=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the contact URI for the author or publisher of the content.



Get: ReferralInfoUri(self: PublishLicense) -> Uri



"""

 UseLicenseAcquisitionUrl=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the URI to use for acquiring a System.Security.RightsManagement.UseLicense.



Get: UseLicenseAcquisitionUrl(self: PublishLicense) -> Uri



"""



class RightsManagementException(Exception,ISerializable,_Exception):
 """
 Represents an error condition when a rights management operation cannot complete successfully.

 

 RightsManagementException()

 RightsManagementException(message: str)

 RightsManagementException(message: str,innerException: Exception)

 RightsManagementException(failureCode: RightsManagementFailureCode)

 RightsManagementException(failureCode: RightsManagementFailureCode,message: str)

 RightsManagementException(failureCode: RightsManagementFailureCode,innerException: Exception)

 RightsManagementException(failureCode: RightsManagementFailureCode,message: str,innerException: Exception)
 """
 def add_SerializeObjectState(self,*args):
  """ add_SerializeObjectState(self: Exception,value: EventHandler[SafeSerializationEventArgs]) """
  pass
 def GetObjectData(self,info,context):
  """
  GetObjectData(self: RightsManagementException,info: SerializationInfo,context: StreamingContext)

   Sets the System.Runtime.Serialization.SerializationInfo store with the parameter name and 

    information about the exception.

  

  

   info: The object that holds the serialized data.

   context: The contextual information about the source or destination.
  """
  pass
 def remove_SerializeObjectState(self,*args):
  """ remove_SerializeObjectState(self: Exception,value: EventHandler[SafeSerializationEventArgs]) """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type)

  __new__(cls: type,message: str)

  __new__(cls: type,message: str,innerException: Exception)

  __new__(cls: type,failureCode: RightsManagementFailureCode)

  __new__(cls: type,failureCode: RightsManagementFailureCode,message: str)

  __new__(cls: type,failureCode: RightsManagementFailureCode,innerException: Exception)

  __new__(cls: type,failureCode: RightsManagementFailureCode,message: str,innerException: Exception)

  __new__(cls: type,info: SerializationInfo,context: StreamingContext)
  """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 FailureCode=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Security.RightsManagement.RightsManagementFailureCode for the error.



Get: FailureCode(self: RightsManagementException) -> RightsManagementFailureCode



"""



class RightsManagementFailureCode(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies error conditions that can occur when performing a rights management operation.

 

 enum RightsManagementFailureCode,values: Aborted (-2147168447),ActivationFailed (-2147168448),AdEntryNotFound (-2147168419),AlreadyInProgress (-2147168456),AuthenticationFailed (-2147168445),BadGetInfoQuery (-2147168494),BindAccessPrincipalNotEnabling (-2147168478),BindAccessUnsatisfied (-2147168477),BindContentNotInEndUseLicense (-2147168479),BindIndicatedPrincipalMissing (-2147168476),BindIntervalTimeViolated (-2147168465),BindMachineNotFoundInGroupIdentity (-2147168475),BindNoApplicableRevocationList (-2147168472),BindNoSatisfiedRightsGroup (-2147168464),BindPolicyViolation (-2147168485),BindRevocationListStale (-2147168473),BindRevokedIssuer (-2147168483),BindRevokedLicense (-2147168484),BindRevokedModule (-2147168480),BindRevokedPrincipal (-2147168482),BindRevokedResource (-2147168481),BindSpecifiedWorkMissing (-2147168463),BindValidityTimeViolated (-2147168488),BrokenCertChain (-2147168487),ClockRollbackDetected (-2147168491),CryptoOperationUnsupported (-2147168492),DebuggerDetected (-2147168416),EmailNotVerified (-2147168422),EnablingPrincipalFailure (-2147168496),EncryptionNotPermitted (-2147168508),EnvironmentCannotLoad (-2147168501),EnvironmentNotLoaded (-2147168502),ExpiredOfficialIssuanceLicenseTemplate (-2147168425),GlobalOptionAlreadySet (-2147168396),GroupIdentityNotSet (-2147168455),HidCorrupted (-2147168442),HidInvalid (-2147168423),IdMismatch (-2147168459),IncompatibleObjects (-2147168498),InfoNotInLicense (-2147168511),InfoNotPresent (-2147168495),InstallationFailed (-2147168443),InvalidAlgorithmType (-2147168503),InvalidClientLicensorCertificate (-2147168424),InvalidEmail (-2147168437),InvalidEncodingType (-2147168505),InvalidHandle (-2147168468),InvalidIssuanceLicenseTemplate (-2147168428),InvalidKeyLength (-2147168427),InvalidLicense (-2147168512),InvalidLicenseSignature (-2147168510),InvalidLockboxPath (-2147168399),InvalidLockboxType (-2147168400),InvalidNumericalValue (-2147168504),InvalidRegistryPath (-2147168398),InvalidServerResponse (-2147168441),InvalidTimeInfo (-2147168431),InvalidVersion (-2147168506),KeyTypeUnsupported (-2147168493),LibraryFail (-2147168497),LibraryUnsupportedPlugIn (-2147168474),LicenseAcquisitionFailed (-2147168460),LicenseBindingToWindowsIdentityFailed (-2147168429),ManifestPolicyViolation (-2147183860),MetadataNotSet (-2147168433),NeedsGroupIdentityActivation (-2147168450),NeedsMachineActivation (-2147168451),NoAesCryptoProvider (-2147168397),NoConnect (-2147168453),NoDistributionPointUrlFound (-2147168457),NoLicense (-2147168452),NoMoreData (-2147168461),NotAChain (-2147168418),NotSet (-2147168434),OutdatedModule (-2147168435),OutOfQuota (-2147168446),OwnerLicenseNotFound (-2147168395),QueryReportsNoResults (-2147168490),RecordNotFound (-2147168454),RequestDenied (-2147168417),RevocationInfoNotSet (-2147168432),RightNotGranted (-2147168507),RightNotSet (-2147168430),ServerError (-2147168444),ServerNotFound (-2147168438),ServiceGone (-2147168420),ServiceMoved (-2147168421),ServiceNotFound (-2147168440),Success (0),TooManyCertificates (-2147168458),TooManyLoadedEnvironments (-2147168500),UnexpectedException (-2147168489),UseDefault (-2147168439),ValidityTimeViolation (-2147168436)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Aborted=None
 ActivationFailed=None
 AdEntryNotFound=None
 AlreadyInProgress=None
 AuthenticationFailed=None
 BadGetInfoQuery=None
 BindAccessPrincipalNotEnabling=None
 BindAccessUnsatisfied=None
 BindContentNotInEndUseLicense=None
 BindIndicatedPrincipalMissing=None
 BindIntervalTimeViolated=None
 BindMachineNotFoundInGroupIdentity=None
 BindNoApplicableRevocationList=None
 BindNoSatisfiedRightsGroup=None
 BindPolicyViolation=None
 BindRevocationListStale=None
 BindRevokedIssuer=None
 BindRevokedLicense=None
 BindRevokedModule=None
 BindRevokedPrincipal=None
 BindRevokedResource=None
 BindSpecifiedWorkMissing=None
 BindValidityTimeViolated=None
 BrokenCertChain=None
 ClockRollbackDetected=None
 CryptoOperationUnsupported=None
 DebuggerDetected=None
 EmailNotVerified=None
 EnablingPrincipalFailure=None
 EncryptionNotPermitted=None
 EnvironmentCannotLoad=None
 EnvironmentNotLoaded=None
 ExpiredOfficialIssuanceLicenseTemplate=None
 GlobalOptionAlreadySet=None
 GroupIdentityNotSet=None
 HidCorrupted=None
 HidInvalid=None
 IdMismatch=None
 IncompatibleObjects=None
 InfoNotInLicense=None
 InfoNotPresent=None
 InstallationFailed=None
 InvalidAlgorithmType=None
 InvalidClientLicensorCertificate=None
 InvalidEmail=None
 InvalidEncodingType=None
 InvalidHandle=None
 InvalidIssuanceLicenseTemplate=None
 InvalidKeyLength=None
 InvalidLicense=None
 InvalidLicenseSignature=None
 InvalidLockboxPath=None
 InvalidLockboxType=None
 InvalidNumericalValue=None
 InvalidRegistryPath=None
 InvalidServerResponse=None
 InvalidTimeInfo=None
 InvalidVersion=None
 KeyTypeUnsupported=None
 LibraryFail=None
 LibraryUnsupportedPlugIn=None
 LicenseAcquisitionFailed=None
 LicenseBindingToWindowsIdentityFailed=None
 ManifestPolicyViolation=None
 MetadataNotSet=None
 NeedsGroupIdentityActivation=None
 NeedsMachineActivation=None
 NoAesCryptoProvider=None
 NoConnect=None
 NoDistributionPointUrlFound=None
 NoLicense=None
 NoMoreData=None
 NotAChain=None
 NotSet=None
 OutdatedModule=None
 OutOfQuota=None
 OwnerLicenseNotFound=None
 QueryReportsNoResults=None
 RecordNotFound=None
 RequestDenied=None
 RevocationInfoNotSet=None
 RightNotGranted=None
 RightNotSet=None
 ServerError=None
 ServerNotFound=None
 ServiceGone=None
 ServiceMoved=None
 ServiceNotFound=None
 Success=None
 TooManyCertificates=None
 TooManyLoadedEnvironments=None
 UnexpectedException=None
 UseDefault=None
 ValidityTimeViolation=None
 value__=None


class SecureEnvironment(object,IDisposable):
 """ Represents a secure client session for user activation,license binding,and other rights management operations. """
 @staticmethod
 def Create(applicationManifest,*__args):
  """
  Create(applicationManifest: str,authentication: AuthenticationType,userActivationMode: UserActivationMode) -> SecureEnvironment

  

   Creates a secure client session given an application rights manifest,

    System.Security.RightsManagement.AuthenticationType,and 

    System.Security.RightsManagement.UserActivationMode.

  

  

   applicationManifest: The application rights manifest.

   authentication: The method of authentication.

   userActivationMode: The type of the user rights account certificate.

   Returns: A secure client session for activation,license binding,and other rights management operations.

  Create(applicationManifest: str,user: ContentUser) -> SecureEnvironment

  

   Creates a secure client session for a specified user with a given rights manifest.

  

   applicationManifest: The application rights manifest.

   user: The user or user-group for granting access to rights managed content.

   Returns: A secure client session for activation,license binding,and other rights management operations.
  """
  pass
 def Dispose(self):
  """
  Dispose(self: SecureEnvironment)

   Releases all resources used by the System.Security.RightsManagement.SecureEnvironment.
  """
  pass
 @staticmethod
 def GetActivatedUsers():
  """
  GetActivatedUsers() -> ReadOnlyCollection[ContentUser]

  

   Returns a list of the activated users.

   Returns: A list of the currently activated users.
  """
  pass
 @staticmethod
 def IsUserActivated(user):
  """
  IsUserActivated(user: ContentUser) -> bool

  

   Indicates whether a given user has been activated for accessing rights managed content.

  

   user: The user or user-group for granting access to rights managed content.

   Returns: true if the given user has been activated for accessing rights managed content; otherwise,false.
  """
  pass
 @staticmethod
 def RemoveActivatedUser(user):
  """
  RemoveActivatedUser(user: ContentUser)

   Removes the license activation for a specified user.

  

   user: The user to remove the license activation for.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 ApplicationManifest=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Security.RightsManagement.SecureEnvironment.ApplicationManifest specified when the System.Security.RightsManagement.SecureEnvironment was created.



Get: ApplicationManifest(self: SecureEnvironment) -> str



"""

 User=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the user or user-group specified when the System.Security.RightsManagement.SecureEnvironment was created.



Get: User(self: SecureEnvironment) -> ContentUser



"""



class UnsignedPublishLicense(object):
 """
 Represents an unsigned rights managed�System.Security.RightsManagement.PublishLicense or an unsigned System.Security.RightsManagement.PublishLicense template.

 

 UnsignedPublishLicense()

 UnsignedPublishLicense(publishLicenseTemplate: str)
 """
 def Sign(self,secureEnvironment,authorUseLicense):
  """
  Sign(self: UnsignedPublishLicense,secureEnvironment: SecureEnvironment) -> (PublishLicense,UseLicense)

  

   Creates a signed System.Security.RightsManagement.PublishLicense and returns a 

    System.Security.RightsManagement.UseLicense for the document author.

  

  

   secureEnvironment: The secure environment for license activation and binding.

   Returns: The signed System.Security.RightsManagement.PublishLicense that is created by signing this 

    System.Security.RightsManagement.UnsignedPublishLicense.
  """
  pass
 def ToString(self):
  """
  ToString(self: UnsignedPublishLicense) -> str

  

   Returns a serialized template created from the XrML of the 

    System.Security.RightsManagement.UnsignedPublishLicense.

  

   Returns: A serialized template created from the XrML of the 

    System.Security.RightsManagement.UnsignedPublishLicense.
  """
  pass
 @staticmethod
 def __new__(self,publishLicenseTemplate=None):
  """
  __new__(cls: type)

  __new__(cls: type,publishLicenseTemplate: str)
  """
  pass
 ContentId=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the publisher-created content identifier.



Get: ContentId(self: UnsignedPublishLicense) -> Guid



Set: ContentId(self: UnsignedPublishLicense)=value

"""

 Grants=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a collection of assigned user rights.



Get: Grants(self: UnsignedPublishLicense) -> ICollection[ContentGrant]



"""

 LocalizedNameDescriptionDictionary=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a collection of name and description pairs.



Get: LocalizedNameDescriptionDictionary(self: UnsignedPublishLicense) -> IDictionary[int,LocalizedNameDescriptionPair]



"""

 Owner=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the content owner.



Get: Owner(self: UnsignedPublishLicense) -> ContentUser



Set: Owner(self: UnsignedPublishLicense)=value

"""

 ReferralInfoName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the contact name for the author or publisher of the content.



Get: ReferralInfoName(self: UnsignedPublishLicense) -> str



Set: ReferralInfoName(self: UnsignedPublishLicense)=value

"""

 ReferralInfoUri=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the contact URI for the author or publisher of the content.



Get: ReferralInfoUri(self: UnsignedPublishLicense) -> Uri



Set: ReferralInfoUri(self: UnsignedPublishLicense)=value

"""



class UseLicense(object):
 """
 Represents a license that enables access to protected rights managed content.

 

 UseLicense(useLicense: str)
 """
 def Bind(self,secureEnvironment):
  """
  Bind(self: UseLicense,secureEnvironment: SecureEnvironment) -> CryptoProvider

  

   Binds the license to a given System.Security.RightsManagement.SecureEnvironment.

  

   secureEnvironment: The environment to bind the license to.

   Returns: A System.Security.RightsManagement.CryptoProvider instance if the license binding succeeded; 

    otherwise,null.
  """
  pass
 def Equals(self,x):
  """
  Equals(self: UseLicense,x: object) -> bool

  

   Indicates if this license is equivalent to another given license.

  

   x: The license to compare.

   Returns: true if both licenses are the equivalent; otherwise,false.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: UseLicense) -> int

  

   Returns the hash code associated with this license.

   Returns: A hash code for this license.
  """
  pass
 def ToString(self):
  """
  ToString(self: UseLicense) -> str

  

   Returns the serialized XrML string used to create this license.

   Returns: The serialized Extensible Rights Markup Language (XrML) string originally passed to the 

    System.Security.RightsManagement.UseLicense.#ctor(System.String) constructor.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 @staticmethod
 def __new__(self,useLicense):
  """ __new__(cls: type,useLicense: str) """
  pass
 def __ne__(self,*args):
  pass
 ApplicationData=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the application data dictionary that contains key/value pairs passed from the publishing application to the consuming application.



Get: ApplicationData(self: UseLicense) -> IDictionary[str,str]



"""

 ContentId=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the content identifier created by the publisher.



Get: ContentId(self: UseLicense) -> Guid



"""

 Owner=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the owner of the license.



Get: Owner(self: UseLicense) -> ContentUser



"""



class UserActivationMode(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the type of user Rights Account Certificate to request for rights management activation.

 

 enum UserActivationMode,values: Permanent (0),Temporary (1)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Permanent=None
 Temporary=None
 value__=None





class DataGridViewCellEventArgs(EventArgs):
 """
 Provides data for System.Windows.Forms.DataGridView events related to cell and row operations.

 

 DataGridViewCellEventArgs(columnIndex: int,rowIndex: int)
 """
 @staticmethod
 def __new__(self,columnIndex,rowIndex):
  """ __new__(cls: type,columnIndex: int,rowIndex: int) """
  pass
 ColumnIndex=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating the column index of the cell that the event occurs for.



Get: ColumnIndex(self: DataGridViewCellEventArgs) -> int



"""

 RowIndex=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating the row index of the cell that the event occurs for.



Get: RowIndex(self: DataGridViewCellEventArgs) -> int



"""





"""Prepare and compile url script types."""
from pyrevit.coreutils import logger

from pyrevit.runtime import bundletypemaker


#pylint: disable=W0703,C0302,C0103
mlogger = logger.get_logger(__name__)


def create_executor_type(extension, module_builder, cmd_component):
    """Create the dotnet type for the executor.

    Args:
        extension (Extension): pyRevit extension
        module_builder (ModuleBuilder): module builder
        cmd_component (GenericUICommand): command component
    """
    cmd_component.arguments = [cmd_component.get_target_url()]
    bundletypemaker.create_executor_type(
        extension,
        module_builder,
        cmd_component
        )



class IComponentEditorPageSite:
 """ The site for a System.Windows.Forms.Design.ComponentEditorPage. """
 def GetControl(self):
  """
  GetControl(self: IComponentEditorPageSite) -> Control

  

   Returns the parent control for the page window.

   Returns: The parent control for the page window.
  """
  pass
 def SetDirty(self):
  """
  SetDirty(self: IComponentEditorPageSite)

   Notifies the site that the editor is in a modified state.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass



r"""Python wrapper for Autodesk Revit Server.

This is a python module for interacting with Autodesk Revit Server using
its RESTful API. This module requires 'requests' module for handling http
requests to the Revit Server.

Module Files:
    exceptions.py: Defines module exceptions and custom exceptions for
                   http status codes returned by the server

    api.py: Documents all standard keys that are returned in JSON
            dictionaries from server API calls.

    models.py: Defines classes and namedtuples that wrap the data
               returned from server API calls.

    server.py: Defines the server wrapper class. RevitServer class aims to
               support all the Revit Server API functionality.

Example:
    >>> name = '<server name>'
    >>> version = '2017'    # server version in XXXX format
    >>> rserver = RevitServer(name, version)
    >>> # listing all files, folders, and models in a server
    >>> for parent, folders, files, models in rserver.walk():
    ...     print(parent)
    ...     for fd in folders:
    ...         print('\t@d {}'.format(fd.path))
    ...     for f in files:
    ...         print('\t@f {}'.format(f.path))
    ...     for m in models:
    ...         print('\t@m {}'.format(m.path))

"""


__version__ = "1.1.0"


from rpws.exceptions import *
from rpws.server import RevitServer



class FormCollection(ReadOnlyCollectionBase,ICollection,IEnumerable):
 """
 Represents a collection of System.Windows.Forms.Form objects.

 

 FormCollection()
 """
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y]x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 InnerList=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the list of elements contained in the System.Collections.ReadOnlyCollectionBase instance.



"""





class IListSource:
 """ Provides functionality to an object to return a list that can be bound to a data source. """
 def GetList(self):
  """
  GetList(self: IListSource) -> IList

  

   Returns an System.Collections.IList that can be bound to a data source from an object that does 

    not implement an System.Collections.IList itself.

  

   Returns: An System.Collections.IList that can be bound to a data source from the object.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 ContainsListCollection=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the collection is a collection of System.Collections.IList objects.



Get: ContainsListCollection(self: IListSource) -> bool



"""





class ColumnWidthChangedEventArgs(EventArgs):
 """
 Provides data for the System.Windows.Forms.ListView.ColumnWidthChanged event.

 

 ColumnWidthChangedEventArgs(columnIndex: int)
 """
 @staticmethod
 def __new__(self,columnIndex):
  """ __new__(cls: type,columnIndex: int) """
  pass
 ColumnIndex=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the column index for the column whose width is being changed.



Get: ColumnIndex(self: ColumnWidthChangedEventArgs) -> int



"""





class ToolStripDropDownClosingEventArgs(CancelEventArgs):
 """
 Provides data for the System.Windows.Forms.ToolStripDropDown.Closing event.

 

 ToolStripDropDownClosingEventArgs(reason: ToolStripDropDownCloseReason)
 """
 @staticmethod
 def __new__(self,reason):
  """ __new__(cls: type,reason: ToolStripDropDownCloseReason) """
  pass
 CloseReason=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the reason that the System.Windows.Forms.ToolStripDropDown is closing.



Get: CloseReason(self: ToolStripDropDownClosingEventArgs) -> ToolStripDropDownCloseReason



"""





class LinkArea(object):
 """
 Represents an area within a System.Windows.Forms.LinkLabel control that represents a hyperlink within the control.

 

 LinkArea(start: int,length: int)
 """
 def Equals(self,o):
  """
  Equals(self: LinkArea,o: object) -> bool

  

   Determines whether this System.Windows.Forms.LinkArea is equal to the specified object.

  

   o: The object to compare to this System.Windows.Forms.LinkArea.

   Returns: true if the specified object is equal to the current System.Windows.Forms.LinkArea; otherwise,

    false.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: LinkArea) -> int

   Returns: A 32-bit signed integer that is the hash code for this instance.
  """
  pass
 def ToString(self):
  """ ToString(self: LinkArea) -> str """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 @staticmethod
 def __new__(self,start,length):
  """
  __new__(cls: type,start: int,length: int)

  __new__[LinkArea]() -> LinkArea
  """
  pass
 def __ne__(self,*args):
  pass
 IsEmpty=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the System.Windows.Forms.LinkArea is empty.



Get: IsEmpty(self: LinkArea) -> bool



"""

 Length=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the number of characters in the link area.



Get: Length(self: LinkArea) -> int



Set: Length(self: LinkArea)=value

"""

 Start=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the starting location of the link area within the text of the System.Windows.Forms.LinkLabel.



Get: Start(self: LinkArea) -> int



Set: Start(self: LinkArea)=value

"""


 LinkAreaConverter=None




class UCOMIStream:
 """ Use System.Runtime.InteropServices.ComTypes.IStream instead. """
 def Clone(self,ppstm):
  """
  Clone(self: UCOMIStream) -> UCOMIStream

  

   Creates a new stream object with its own seek pointer that references the same bytes as the 

    original stream.
  """
  pass
 def Commit(self,grfCommitFlags):
  """
  Commit(self: UCOMIStream,grfCommitFlags: int)

   Ensures that any changes made to a stream object open in transacted mode are reflected in the 

    parent storage.

  

  

   grfCommitFlags: Controls how the changes for the stream object are committed.
  """
  pass
 def CopyTo(self,pstm,cb,pcbRead,pcbWritten):
  """
  CopyTo(self: UCOMIStream,pstm: UCOMIStream,cb: Int64,pcbRead: IntPtr,pcbWritten: IntPtr)

   Copies a specified number of bytes from the current seek pointer in the stream to the current 

    seek pointer in another stream.

  

  

   pstm: Reference to the destination stream.

   cb: The number of bytes to copy from the source stream.

   pcbRead: On successful return,contains the actual number of bytes read from the source.

   pcbWritten: On successful return,contains the actual number of bytes written to the destination.
  """
  pass
 def LockRegion(self,libOffset,cb,dwLockType):
  """
  LockRegion(self: UCOMIStream,libOffset: Int64,cb: Int64,dwLockType: int)

   Restricts access to a specified range of bytes in the stream.

  

   libOffset: The byte offset for the beginning of the range.

   cb: The length of the range,in bytes,to restrict.

   dwLockType: The requested restrictions on accessing the range.
  """
  pass
 def Read(self,pv,cb,pcbRead):
  """
  Read(self: UCOMIStream,cb: int,pcbRead: IntPtr) -> Array[Byte]

  

   Reads a specified number of bytes from the stream object into memory starting at the current 

    seek pointer.

  

  

   cb: The number of bytes to read from the stream object.

   pcbRead: Pointer to a ULONG variable that receives the actual number of bytes read from the stream object.
  """
  pass
 def Revert(self):
  """
  Revert(self: UCOMIStream)

   Discards all changes that have been made to a transacted stream since the last 

    System.Runtime.InteropServices.UCOMIStream.Commit(System.Int32) call.
  """
  pass
 def Seek(self,dlibMove,dwOrigin,plibNewPosition):
  """
  Seek(self: UCOMIStream,dlibMove: Int64,dwOrigin: int,plibNewPosition: IntPtr)

   Changes the seek pointer to a new location relative to the beginning of the stream,to the end 

    of the stream,or to the current seek pointer.

  

  

   dlibMove: Displacement to add to dwOrigin.

   dwOrigin: Specifies the origin of the seek. The origin can be the beginning of the file,the current seek 

    pointer,or the end of the file.

  

   plibNewPosition: On successful return,contains the offset of the seek pointer from the beginning of the stream.
  """
  pass
 def SetSize(self,libNewSize):
  """
  SetSize(self: UCOMIStream,libNewSize: Int64)

   Changes the size of the stream object.

  

   libNewSize: Specifies the new size of the stream as a number of bytes.
  """
  pass
 def Stat(self,pstatstg,grfStatFlag):
  """
  Stat(self: UCOMIStream,grfStatFlag: int) -> STATSTG

  

   Retrieves the System.Runtime.InteropServices.STATSTG structure for this stream.

  

   grfStatFlag: Specifies some of the members in the STATSTG structure that this method does not return,thus 

    saving some memory allocation operations.
  """
  pass
 def UnlockRegion(self,libOffset,cb,dwLockType):
  """
  UnlockRegion(self: UCOMIStream,libOffset: Int64,cb: Int64,dwLockType: int)

   Removes the access restriction on a range of bytes previously restricted with 

    System.Runtime.InteropServices.UCOMIStream.LockRegion(System.Int64,System.Int64,System.Int32).

  

  

   libOffset: The byte offset for the beginning of the range.

   cb: The length,in bytes,of the range to restrict.

   dwLockType: The access restrictions previously placed on the range.
  """
  pass
 def Write(self,pv,cb,pcbWritten):
  """
  Write(self: UCOMIStream,pv: Array[Byte],cb: int,pcbWritten: IntPtr)

   Writes a specified number of bytes into the stream object starting at the current seek pointer.

  

   pv: Buffer to write this stream to.

   cb: The number of bytes to write into the stream.

   pcbWritten: On successful return,contains the actual number of bytes written to the stream object. The 

    caller can set this pointer to null,in which case this method does not provide the actual 

    number of bytes written.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass



class IDataGridColumnStyleEditingNotificationService:
 """ Provides an editing notification interface. """
 def ColumnStartedEditing(self,editingControl):
  """
  ColumnStartedEditing(self: IDataGridColumnStyleEditingNotificationService,editingControl: Control)

   Informs the System.Windows.Forms.DataGrid that the user has begun editing the column.

  

   editingControl: The System.Windows.Forms.Control that is editing the column.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass



class GridColumnStylesCollection(BaseCollection,ICollection,IEnumerable,IList):
 """ Represents a collection of System.Windows.Forms.DataGridColumnStyle objects in the System.Windows.Forms.DataGrid control. """
 def Add(self,column):
  """
  Add(self: GridColumnStylesCollection,column: DataGridColumnStyle) -> int

  

   Adds a column style to the collection.

  

   column: The System.Windows.Forms.DataGridColumnStyle to add.

   Returns: The index of the new System.Windows.Forms.DataGridColumnStyle.
  """
  pass
 def AddRange(self,columns):
  """
  AddRange(self: GridColumnStylesCollection,columns: Array[DataGridColumnStyle])

   Adds an array of column style objects to the collection.

  

   columns: An array of System.Windows.Forms.DataGridColumnStyle objects to add to the collection.
  """
  pass
 def Clear(self):
  """
  Clear(self: GridColumnStylesCollection)

   Clears the collection of System.Windows.Forms.DataGridColumnStyle objects.
  """
  pass
 def Contains(self,*__args):
  """
  Contains(self: GridColumnStylesCollection,name: str) -> bool

  

   Gets a value indicating whether the System.Windows.Forms.GridColumnStylesCollection contains the 

    System.Windows.Forms.DataGridColumnStyle with the specified name.

  

  

   name: The System.Windows.Forms.DataGridColumnStyle.MappingName of the desired 

    System.Windows.Forms.DataGridColumnStyle.

  

   Returns: true if the collection contains the System.Windows.Forms.DataGridColumnStyle; otherwise,false.

  Contains(self: GridColumnStylesCollection,column: DataGridColumnStyle) -> bool

  

   Gets a value indicating whether the System.Windows.Forms.GridColumnStylesCollection contains the 

    specified System.Windows.Forms.DataGridColumnStyle.

  

  

   column: The desired System.Windows.Forms.DataGridColumnStyle.

   Returns: true if the collection contains the System.Windows.Forms.DataGridColumnStyle; otherwise,false.

  Contains(self: GridColumnStylesCollection,propertyDescriptor: PropertyDescriptor) -> bool

  

   Gets a value indicating whether the System.Windows.Forms.GridColumnStylesCollection contains a 

    System.Windows.Forms.DataGridColumnStyle associated with the specified 

    System.ComponentModel.PropertyDescriptor.

  

  

   propertyDescriptor: The System.ComponentModel.PropertyDescriptor associated with the desired 

    System.Windows.Forms.DataGridColumnStyle.

  

   Returns: true if the collection contains the System.Windows.Forms.DataGridColumnStyle; otherwise,false.
  """
  pass
 def IndexOf(self,element):
  """
  IndexOf(self: GridColumnStylesCollection,element: DataGridColumnStyle) -> int

  

   Gets the index of a specified System.Windows.Forms.DataGridColumnStyle.

  

   element: The System.Windows.Forms.DataGridColumnStyle to find.

   Returns: The zero-based index of the System.Windows.Forms.DataGridColumnStyle within the 

    System.Windows.Forms.GridColumnStylesCollection or -1 if no corresponding 

    System.Windows.Forms.DataGridColumnStyle exists.
  """
  pass
 def MemberwiseClone(self,*args):
  """
  MemberwiseClone(self: MarshalByRefObject,cloneIdentity: bool) -> MarshalByRefObject

  

   Creates a shallow copy of the current System.MarshalByRefObject object.

  

   cloneIdentity: false to delete the current System.MarshalByRefObject object's identity,which will cause the 

    object to be assigned a new identity when it is marshaled across a remoting boundary. A value of 

    false is usually appropriate. true to copy the current System.MarshalByRefObject object's 

    identity to its clone,which will cause remoting client calls to be routed to the remote server 

    object.

  

   Returns: A shallow copy of the current System.MarshalByRefObject object.

  MemberwiseClone(self: object) -> object

  

   Creates a shallow copy of the current System.Object.

   Returns: A shallow copy of the current System.Object.
  """
  pass
 def OnCollectionChanged(self,*args):
  """
  OnCollectionChanged(self: GridColumnStylesCollection,e: CollectionChangeEventArgs)

   Raises the System.Windows.Forms.GridColumnStylesCollection.CollectionChanged event.

  

   e: A System.ComponentModel.CollectionChangeEventArgs that contains the event data event.
  """
  pass
 def Remove(self,column):
  """
  Remove(self: GridColumnStylesCollection,column: DataGridColumnStyle)

   Removes the specified System.Windows.Forms.DataGridColumnStyle from the 

    System.Windows.Forms.GridColumnStylesCollection.

  

  

   column: The System.Windows.Forms.DataGridColumnStyle to remove from the collection.
  """
  pass
 def RemoveAt(self,index):
  """
  RemoveAt(self: GridColumnStylesCollection,index: int)

   Removes the System.Windows.Forms.DataGridColumnStyle with the specified index from the 

    System.Windows.Forms.GridColumnStylesCollection.

  

  

   index: The zero-based index of the System.Windows.Forms.DataGridColumnStyle to remove.
  """
  pass
 def ResetPropertyDescriptors(self):
  """
  ResetPropertyDescriptors(self: GridColumnStylesCollection)

   Sets the System.ComponentModel.PropertyDescriptor for each column style in the collection to 

    null.
  """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+y """
  pass
 def __contains__(self,*args):
  """
  __contains__(self: IList,value: object) -> bool

  

   Determines whether the System.Collections.IList contains a specific value.

  

   value: The object to locate in the System.Collections.IList.

   Returns: true if the System.Object is found in the System.Collections.IList; otherwise,false.
  """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y]x.__getitem__(y) <==> x[y]x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 def __len__(self,*args):
  """ x.__len__() <==> len(x) """
  pass
 List=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the list of items in the collection.



"""


 CollectionChanged=None




class DescriptionAttribute(Attribute,_Attribute):
 """
 Specifies a description for a property or event.

 

 DescriptionAttribute()

 DescriptionAttribute(description: str)
 """
 def Equals(self,obj):
  """
  Equals(self: DescriptionAttribute,obj: object) -> bool

  

   Returns whether the value of the given object is equal to the current 

    System.ComponentModel.DescriptionAttribute.

  

  

   obj: The object to test the value equality of.

   Returns: true if the value of the given object is equal to that of the current; otherwise,false.
  """
  pass
 def GetHashCode(self):
  """ GetHashCode(self: DescriptionAttribute) -> int """
  pass
 def IsDefaultAttribute(self):
  """
  IsDefaultAttribute(self: DescriptionAttribute) -> bool

  

   Returns a value indicating whether this is the default 

    System.ComponentModel.DescriptionAttribute instance.

  

   Returns: true,if this is the default System.ComponentModel.DescriptionAttribute instance; otherwise,

    false.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,description=None):
  """
  __new__(cls: type)

  __new__(cls: type,description: str)
  """
  pass
 def __ne__(self,*args):
  pass
 Description=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the description stored in this attribute.



Get: Description(self: DescriptionAttribute) -> str



"""

 DescriptionValue=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the string stored as the description.



"""


 Default=None




class WebPermissionAttribute(CodeAccessSecurityAttribute,_Attribute):
 """
 Specifies permission to access Internet resources. This class cannot be inherited.

 

 WebPermissionAttribute(action: SecurityAction)
 """
 def CreatePermission(self):
  """
  CreatePermission(self: WebPermissionAttribute) -> IPermission

  

   Creates and returns a new instance of the System.Net.WebPermission class.

   Returns: A System.Net.WebPermission corresponding to the security declaration.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,action):
  """ __new__(cls: type,action: SecurityAction) """
  pass
 def __reduce_ex__(self,*args):
  pass
 Accept=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the URI string accepted by the current System.Net.WebPermissionAttribute.



Get: Accept(self: WebPermissionAttribute) -> str



Set: Accept(self: WebPermissionAttribute)=value

"""

 AcceptPattern=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a regular expression pattern that describes the URI accepted by the current System.Net.WebPermissionAttribute.



Get: AcceptPattern(self: WebPermissionAttribute) -> str



Set: AcceptPattern(self: WebPermissionAttribute)=value

"""

 Connect=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the URI connection string controlled by the current System.Net.WebPermissionAttribute.



Get: Connect(self: WebPermissionAttribute) -> str



Set: Connect(self: WebPermissionAttribute)=value

"""

 ConnectPattern=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a regular expression pattern that describes the URI connection controlled by the current System.Net.WebPermissionAttribute.



Get: ConnectPattern(self: WebPermissionAttribute) -> str



Set: ConnectPattern(self: WebPermissionAttribute)=value

"""





""" Ready to use FlexForms. Replaces old forms """  #

import sys

from rpw.ui.forms.flexform import FlexForm, Label, ComboBox, TextBox, Button

def SelectFromList(title, options, description=None, sort=True, exit_on_close=True):
    """ Simple FlexForm wrapped function with ComboBox and button

    Args:
        title (str): Title of form
        options (dict,list[str]): Dictionary (string keys) or List[strings]
        description (str): Optional Description of input requested  [default: None]
        sort (bool): Optional sort flag - sorts keys [default: True]
        exit_on_close (bool): Form will call sys.exit() if Closed on X. [default: True]

    Usage:

        >>> from rpw.ui.forms import SelectFromList
        >>> value = SelectFromList('Test Window', ['1','2','3'])
        >>> # Dropdown shows '1', '2' ,'3'. User clicks Select '1'
        >>> print(value)
        '1'
        >>> # Dictionary
        >>> value = SelectFromList('Test Window', {'Text':str, 'Number':int})
        >>> # User clicks Text
        >>> print(value)
        str
    """
    components = []
    if description:
        components.append(Label(description))
    components.append(ComboBox('combobox', options, sort=sort))
    components.append(Button('Select'))
    form = FlexForm(title, components)
    ok = form.show()
    if ok:
        return form.values['combobox']
    if exit_on_close:
        sys.exit()


def TextInput(title, default=None, description=None, sort=True, exit_on_close=True):
    """ Simple FlexForm wrapped function with TextBox and button

    Args:
        title (str): Title of form
        default (str): Optional default value for text box [default: None]
        description (str): Optional Description of input requested  [default: None]
        exit_on_close (bool): Form will call sys.exit() if Closed on X. [default: True]

    Usage:

        >>> from rpw.ui.forms import TextInput
        >>> value = TextInput('Title', default="3")
        >>> print(value)
        3
    """
    components = []
    if description:
        components.append(Label(description))
    if default:
        textbox = TextBox('textbox', default=default)
    else:
        textbox = TextBox('textbox')
    components.append(textbox)
    components.append(Button('Select'))
    form = FlexForm(title, components)
    ok = form.show()
    if ok:
        return form.values['textbox']
    if exit_on_close:
        sys.exit()


if __name__ == '__main__':
    rv = SelectFromList('Title', ['A','B'], description="Your Options",
                            exit_on_close=True)
    print(rv)

    rv = SelectFromList('Title', {'A':5, 'B':10}, description="Your Options",
                            exit_on_close=True)
    print(rv)

    rv = TextInput('Title', default="3", exit_on_close=True)
    print(rv)
    print('forms.py ran')



class HierarchicalVirtualizationItemDesiredSizes(object):
 """ HierarchicalVirtualizationItemDesiredSizes(logicalSize: Size,logicalSizeInViewport: Size,logicalSizeBeforeViewport: Size,logicalSizeAfterViewport: Size,pixelSize: Size,pixelSizeInViewport: Size,pixelSizeBeforeViewport: Size,pixelSizeAfterViewport: Size) """
 def Equals(self,*__args):
  """
  Equals(self: HierarchicalVirtualizationItemDesiredSizes,comparisonItemSizes: HierarchicalVirtualizationItemDesiredSizes) -> bool

  Equals(self: HierarchicalVirtualizationItemDesiredSizes,oCompare: object) -> bool
  """
  pass
 def GetHashCode(self):
  """ GetHashCode(self: HierarchicalVirtualizationItemDesiredSizes) -> int """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 @staticmethod
 def __new__(self,logicalSize,logicalSizeInViewport,logicalSizeBeforeViewport,logicalSizeAfterViewport,pixelSize,pixelSizeInViewport,pixelSizeBeforeViewport,pixelSizeAfterViewport):
  """
  __new__(cls: type,logicalSize: Size,logicalSizeInViewport: Size,logicalSizeBeforeViewport: Size,logicalSizeAfterViewport: Size,pixelSize: Size,pixelSizeInViewport: Size,pixelSizeBeforeViewport: Size,pixelSizeAfterViewport: Size)

  __new__[HierarchicalVirtualizationItemDesiredSizes]() -> HierarchicalVirtualizationItemDesiredSizes
  """
  pass
 def __ne__(self,*args):
  pass
 LogicalSize=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: LogicalSize(self: HierarchicalVirtualizationItemDesiredSizes) -> Size



"""

 LogicalSizeAfterViewport=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: LogicalSizeAfterViewport(self: HierarchicalVirtualizationItemDesiredSizes) -> Size



"""

 LogicalSizeBeforeViewport=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: LogicalSizeBeforeViewport(self: HierarchicalVirtualizationItemDesiredSizes) -> Size



"""

 LogicalSizeInViewport=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: LogicalSizeInViewport(self: HierarchicalVirtualizationItemDesiredSizes) -> Size



"""

 PixelSize=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: PixelSize(self: HierarchicalVirtualizationItemDesiredSizes) -> Size



"""

 PixelSizeAfterViewport=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: PixelSizeAfterViewport(self: HierarchicalVirtualizationItemDesiredSizes) -> Size



"""

 PixelSizeBeforeViewport=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: PixelSizeBeforeViewport(self: HierarchicalVirtualizationItemDesiredSizes) -> Size



"""

 PixelSizeInViewport=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: PixelSizeInViewport(self: HierarchicalVirtualizationItemDesiredSizes) -> Size



"""





class AmbientValueAttribute(Attribute,_Attribute):
 """
 Specifies the value to pass to a property to cause the property to get its value from another source. This is known as ambience. This class cannot be inherited.

 

 AmbientValueAttribute(type: Type,value: str)

 AmbientValueAttribute(value: Char)

 AmbientValueAttribute(value: Byte)

 AmbientValueAttribute(value: Int16)

 AmbientValueAttribute(value: int)

 AmbientValueAttribute(value: Int64)

 AmbientValueAttribute(value: Single)

 AmbientValueAttribute(value: float)

 AmbientValueAttribute(value: bool)

 AmbientValueAttribute(value: str)

 AmbientValueAttribute(value: object)
 """
 def Equals(self,obj):
  """
  Equals(self: AmbientValueAttribute,obj: object) -> bool

  

   Determines whether the specified System.ComponentModel.AmbientValueAttribute is equal to the 

    current System.ComponentModel.AmbientValueAttribute.

  

  

   obj: The System.ComponentModel.AmbientValueAttribute to compare with the current 

    System.ComponentModel.AmbientValueAttribute.

  

   Returns: true if the specified System.ComponentModel.AmbientValueAttribute is equal to the current 

    System.ComponentModel.AmbientValueAttribute; otherwise,false.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: AmbientValueAttribute) -> int

  

   Returns the hash code for this instance.

   Returns: A hash code for the current System.ComponentModel.AmbientValueAttribute.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type,type: Type,value: str)

  __new__(cls: type,value: Char)

  __new__(cls: type,value: Byte)

  __new__(cls: type,value: Int16)

  __new__(cls: type,value: int)

  __new__(cls: type,value: Int64)

  __new__(cls: type,value: Single)

  __new__(cls: type,value: float)

  __new__(cls: type,value: bool)

  __new__(cls: type,value: str)

  __new__(cls: type,value: object)
  """
  pass
 def __ne__(self,*args):
  pass
 Value=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the object that is the value of this System.ComponentModel.AmbientValueAttribute.



Get: Value(self: AmbientValueAttribute) -> object



"""





class ICredentials:
 """ Provides the base authentication interface for retrieving credentials for Web client authentication. """
 def GetCredential(self,uri,authType):
  """
  GetCredential(self: ICredentials,uri: Uri,authType: str) -> NetworkCredential

  

   Returns a System.Net.NetworkCredential object that is associated with the specified URI,and 

    authentication type.

  

  

   uri: The System.Uri that the client is providing authentication for.

   authType: The type of authentication,as defined in the 

    System.Net.IAuthenticationModule.AuthenticationType property.

  

   Returns: The System.Net.NetworkCredential that is associated with the specified URI and authentication 

    type,or,if no credentials are available,null.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass



class DiscretionaryAcl(CommonAcl,ICollection,IEnumerable):
 """
 Represents a Discretionary Access Control List (DACL).

 

 DiscretionaryAcl(isContainer: bool,isDS: bool,capacity: int)

 DiscretionaryAcl(isContainer: bool,isDS: bool,revision: Byte,capacity: int)

 DiscretionaryAcl(isContainer: bool,isDS: bool,rawAcl: RawAcl)
 """
 def AddAccess(self,accessType,sid,*__args):
  """
  AddAccess(self: DiscretionaryAcl,accessType: AccessControlType,sid: SecurityIdentifier,accessMask: int,inheritanceFlags: InheritanceFlags,propagationFlags: PropagationFlags,objectFlags: ObjectAceFlags,objectType: Guid,inheritedObjectType: Guid)

   Adds an Access Control Entry (ACE) with the specified settings to the current 

    System.Security.AccessControl.DiscretionaryAcl object. Use this method for directory object 

    Access Control Lists (ACLs) when specifying the object type or the inherited object type for the 

    new ACE.

  

  

   accessType: The type of access control (allow or deny) to add.

   sid: The System.Security.Principal.SecurityIdentifier for which to add an ACE.

   accessMask: The access rule for the new ACE.

   inheritanceFlags: Flags that specify the inheritance properties of the new ACE.

   propagationFlags: Flags that specify the inheritance propagation properties for the new ACE.

   objectFlags: Flags that specify if the objectType and inheritedObjectType parameters contain non-null values.

   objectType: The identity of the class of objects to which the new ACE applies.

   inheritedObjectType: The identity of the class of child objects which can inherit the new ACE.

  AddAccess(self: DiscretionaryAcl,accessType: AccessControlType,sid: SecurityIdentifier,rule: ObjectAccessRule)AddAccess(self: DiscretionaryAcl,accessType: AccessControlType,sid: SecurityIdentifier,accessMask: int,inheritanceFlags: InheritanceFlags,propagationFlags: PropagationFlags)

   Adds an Access Control Entry (ACE) with the specified settings to the current 

    System.Security.AccessControl.DiscretionaryAcl object.

  

  

   accessType: The type of access control (allow or deny) to add.

   sid: The System.Security.Principal.SecurityIdentifier for which to add an ACE.

   accessMask: The access rule for the new ACE.

   inheritanceFlags: Flags that specify the inheritance properties of the new ACE.

   propagationFlags: Flags that specify the inheritance propagation properties for the new ACE.
  """
  pass
 def RemoveAccess(self,accessType,sid,*__args):
  """
  RemoveAccess(self: DiscretionaryAcl,accessType: AccessControlType,sid: SecurityIdentifier,accessMask: int,inheritanceFlags: InheritanceFlags,propagationFlags: PropagationFlags,objectFlags: ObjectAceFlags,objectType: Guid,inheritedObjectType: Guid) -> bool

  

   Removes the specified access control rule from the current 

    System.Security.AccessControl.DiscretionaryAcl object. Use this method for directory object 

    Access Control Lists (ACLs) when specifying the object type or the inherited object type.

  

  

   accessType: The type of access control (allow or deny) to remove.

   sid: The System.Security.Principal.SecurityIdentifier for which to remove an access control rule.

   accessMask: The access mask for the access control rule to be removed.

   inheritanceFlags: Flags that specify the inheritance properties of the access control rule to be removed.

   propagationFlags: Flags that specify the inheritance propagation properties for the access control rule to be 

    removed.

  

   objectFlags: Flags that specify if the objectType and inheritedObjectType parameters contain non-null values.

   objectType: The identity of the class of objects to which the removed access control rule applies.

   inheritedObjectType: The identity of the class of child objects which can inherit the removed access control rule.

   Returns: true if this method successfully removes the specified access; otherwise,false.

  RemoveAccess(self: DiscretionaryAcl,accessType: AccessControlType,sid: SecurityIdentifier,rule: ObjectAccessRule) -> bool

  RemoveAccess(self: DiscretionaryAcl,accessType: AccessControlType,sid: SecurityIdentifier,accessMask: int,inheritanceFlags: InheritanceFlags,propagationFlags: PropagationFlags) -> bool

  

   Removes the specified access control rule from the current 

    System.Security.AccessControl.DiscretionaryAcl object.

  

  

   accessType: The type of access control (allow or deny) to remove.

   sid: The System.Security.Principal.SecurityIdentifier for which to remove an access control rule.

   accessMask: The access mask for the rule to be removed.

   inheritanceFlags: Flags that specify the inheritance properties of the rule to be removed.

   propagationFlags: Flags that specify the inheritance propagation properties for the rule to be removed.

   Returns: true if this method successfully removes the specified access; otherwise,false.
  """
  pass
 def RemoveAccessSpecific(self,accessType,sid,*__args):
  """
  RemoveAccessSpecific(self: DiscretionaryAcl,accessType: AccessControlType,sid: SecurityIdentifier,accessMask: int,inheritanceFlags: InheritanceFlags,propagationFlags: PropagationFlags,objectFlags: ObjectAceFlags,objectType: Guid,inheritedObjectType: Guid)

   Removes the specified Access Control Entry (ACE) from the current 

    System.Security.AccessControl.DiscretionaryAcl object. Use this method for directory object 

    Access Control Lists (ACLs) when specifying the object type or the inherited object type for the 

    ACE to be removed.

  

  

   accessType: The type of access control (allow or deny) to remove.

   sid: The System.Security.Principal.SecurityIdentifier for which to remove an ACE.

   accessMask: The access mask for the ACE to be removed.

   inheritanceFlags: Flags that specify the inheritance properties of the ACE to be removed.

   propagationFlags: Flags that specify the inheritance propagation properties for the ACE to be removed.

   objectFlags: Flags that specify if the objectType and inheritedObjectType parameters contain non-null values.

   objectType: The identity of the class of objects to which the removed ACE applies.

   inheritedObjectType: The identity of the class of child objects which can inherit the removed ACE.

  RemoveAccessSpecific(self: DiscretionaryAcl,accessType: AccessControlType,sid: SecurityIdentifier,rule: ObjectAccessRule)RemoveAccessSpecific(self: DiscretionaryAcl,accessType: AccessControlType,sid: SecurityIdentifier,accessMask: int,inheritanceFlags: InheritanceFlags,propagationFlags: PropagationFlags)

   Removes the specified Access Control Entry (ACE) from the current 

    System.Security.AccessControl.DiscretionaryAcl object.

  

  

   accessType: The type of access control (allow or deny) to remove.

   sid: The System.Security.Principal.SecurityIdentifier for which to remove an ACE.

   accessMask: The access mask for the ACE to be removed.

   inheritanceFlags: Flags that specify the inheritance properties of the ACE to be removed.

   propagationFlags: Flags that specify the inheritance propagation properties for the ACE to be removed.
  """
  pass
 def SetAccess(self,accessType,sid,*__args):
  """
  SetAccess(self: DiscretionaryAcl,accessType: AccessControlType,sid: SecurityIdentifier,accessMask: int,inheritanceFlags: InheritanceFlags,propagationFlags: PropagationFlags,objectFlags: ObjectAceFlags,objectType: Guid,inheritedObjectType: Guid)

   Sets the specified access control for the specified System.Security.Principal.SecurityIdentifier 

    object.

  

  

   accessType: The type of access control (allow or deny) to set.

   sid: The System.Security.Principal.SecurityIdentifier for which to set an ACE.

   accessMask: The access rule for the new ACE.

   inheritanceFlags: Flags that specify the inheritance properties of the new ACE.

   propagationFlags: Flags that specify the inheritance propagation properties for the new ACE.

   objectFlags: Flags that specify if the objectType and inheritedObjectType parameters contain non-null values.

   objectType: The identity of the class of objects to which the new ACE applies.

   inheritedObjectType: The identity of the class of child objects which can inherit the new ACE.

  SetAccess(self: DiscretionaryAcl,accessType: AccessControlType,sid: SecurityIdentifier,rule: ObjectAccessRule)SetAccess(self: DiscretionaryAcl,accessType: AccessControlType,sid: SecurityIdentifier,accessMask: int,inheritanceFlags: InheritanceFlags,propagationFlags: PropagationFlags)

   Sets the specified access control for the specified System.Security.Principal.SecurityIdentifier 

    object.

  

  

   accessType: The type of access control (allow or deny) to set.

   sid: The System.Security.Principal.SecurityIdentifier for which to set an ACE.

   accessMask: The access rule for the new ACE.

   inheritanceFlags: Flags that specify the inheritance properties of the new ACE.

   propagationFlags: Flags that specify the inheritance propagation properties for the new ACE.
  """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 @staticmethod
 def __new__(self,isContainer,isDS,*__args):
  """
  __new__(cls: type,isContainer: bool,isDS: bool,capacity: int)

  __new__(cls: type,isContainer: bool,isDS: bool,revision: Byte,capacity: int)

  __new__(cls: type,isContainer: bool,isDS: bool,rawAcl: RawAcl)
  """
  pass
 def __setitem__(self,*args):
  """ x.__setitem__(i,y) <==> x[i]= """
  pass



"""Document colorizer python API."""
#pylint: disable=import-error,invalid-name,broad-except
#pylint: disable=no-member
from pyrevit import HOST_APP
from pyrevit.runtime import types
from pyrevit.framework import Media
from pyrevit.framework import List, Regex
from pyrevit.coreutils import envvars


def hex_to_brush(color_hex):
    """Convert hex color to WPF brush."""
    return Media.SolidColorBrush(
        Media.ColorConverter.ConvertFromString(color_hex)
    )


def hex_from_brush(solid_brush):
    """Convert WPF brush to hex color."""
    color = solid_brush.Color
    color_hex = ''.join(
        '{:02X}'.format(int(x)) for x in
        [color.A, color.R, color.G, color.B]
        )
    return '#' + color_hex


def _get_tabcoloring_cfgs(usercfg):
    # read custom configs for this
    if not usercfg.has_section("tabcoloring"):
        usercfg.add_section("tabcoloring")
    return usercfg.get_section("tabcoloring")


def _get_sort_colorize_docs(tabcfgs):
    return tabcfgs.get_option('sort_colorize_docs', False)


def _set_sort_colorize_docs(tabcfgs, theme):
    tabcfgs.sort_colorize_docs = theme.SortDocTabs


def _get_tab_orderrules(tabcfgs, default=False):
    default_colors = \
        [hex_from_brush(b) for b in types.TabColoringTheme.DefaultBrushes]
    tab_colors = default_colors
    if not default:
        tab_colors = tabcfgs.get_option('tab_colors', default_colors)
    return List[types.TabColoringRule](
        [types.TabColoringRule(hex_to_brush(c)) for c in tab_colors]
        )


def _set_tab_ordercolors(tabcfgs, theme):
    tabcfgs.tab_colors = \
        [hex_from_brush(c.Brush) for c in theme.TabOrderRules]


def _get_tab_filterrules(tabcfgs):
    tab_filtercolors = tabcfgs.get_option('tab_filtercolors', {})
    return List[types.TabColoringRule](
        [types.TabColoringRule(hex_to_brush(c), f)
         for c, f in tab_filtercolors.items()]
    )


def _set_tab_filtercolors(tabcfgs, theme):
    tabcfgs.tab_filtercolors = \
        {hex_from_brush(c.Brush):str(c.TitleFilter)
         for c in theme.TabFilterRules}


def _get_tabstyle(tabcfgs):
    tabstyle_index = tabcfgs.get_option(
        'tabstyle_index',
        types.TabColoringTheme.DefaultTabColoringStyleIndex
        )
    return types.TabColoringTheme.AvailableStyles[tabstyle_index]


def _set_tabstyle(tabcfgs, theme):
    tabcfgs.tabstyle_index = \
        types.TabColoringTheme.AvailableStyles.IndexOf(theme.TabStyle)


def _get_family_tabstyle(tabcfgs):
    family_tabstyle_index = tabcfgs.get_option(
        'family_tabstyle_index',
        types.TabColoringTheme.DefaultFamilyTabColoringStyleIndex
        )
    return types.TabColoringTheme.AvailableStyles[family_tabstyle_index]


def _set_family_tabstyle(tabcfgs, theme):
    tabcfgs.family_tabstyle_index = \
        types.TabColoringTheme.AvailableStyles.IndexOf(theme.FamilyTabStyle)


def get_tabcoloring_theme(usercfg):
    """Get tab coloring theme from settings."""
    tabcfgs = _get_tabcoloring_cfgs(usercfg)

    theme = types.TabColoringTheme()
    theme.SortDocTabs = _get_sort_colorize_docs(tabcfgs)
    theme.TabStyle = _get_tabstyle(tabcfgs)
    theme.FamilyTabStyle = _get_family_tabstyle(tabcfgs)

    theme.TabOrderRules = _get_tab_orderrules(tabcfgs)
    theme.TabFilterRules = _get_tab_filterrules(tabcfgs)

    return theme


def reset_tab_ordercolors(usercfg, theme):
    """Reset tab order colors to internal default."""
    tabcfgs = _get_tabcoloring_cfgs(usercfg)
    theme.TabOrderRules = _get_tab_orderrules(tabcfgs, default=True)


def set_tabcoloring_theme(usercfg, theme):
    """Set tab coloring theme in settings."""
    tabcfgs = _get_tabcoloring_cfgs(usercfg)

    _set_sort_colorize_docs(tabcfgs, theme)
    _set_tabstyle(tabcfgs, theme)
    _set_family_tabstyle(tabcfgs, theme)

    _set_tab_ordercolors(tabcfgs, theme)
    _set_tab_filtercolors(tabcfgs, theme)


def get_tab_orderrule(theme, index):
    """Get coloring rule from active theme, at index."""
    return hex_from_brush(theme.TabOrderRules[index].Brush)


def add_tab_orderrule(theme, color):
    """Add coloring rule to active theme."""
    theme.TabOrderRules.Add(
        types.TabColoringRule(hex_to_brush(color))
        )


def remove_tab_orderrule(theme, index):
    """Remove coloring rule at index, from active theme."""
    theme.TabOrderRules.RemoveAt(index)


def update_tab_orderrule(theme, index, color):
    """Update coloring rule at index, on active theme."""
    tor = theme.TabOrderRules[index]
    tor.Brush = hex_to_brush(color)


def get_tab_filterrule(theme, index):
    """Get coloring filter rule from active theme, at index."""
    tfr = theme.TabFilterRules[index]
    color = tfr.Brush.Color
    color_hex = ''.join(
        '{:02X}'.format(int(x)) for x in
        [color.A, color.R, color.G, color.B]
        )
    return '#' + color_hex, str(tfr.TitleFilter)


def add_tab_filterrule(theme, color, title_filter):
    """Add coloring filter rule to active theme."""
    fc = types.TabColoringRule(hex_to_brush(color), title_filter)
    theme.TabFilterRules.Add(fc)


def remove_tab_filterrule(theme, index):
    """Remove coloring filter rule at index, from active theme."""
    theme.TabFilterRules.RemoveAt(index)


def update_tab_filterrule(theme, index, color=None, title_filter=None):
    """Update coloring filter rule at index, on active theme."""
    tfr = theme.TabFilterRules[index]
    if color:
        tfr.Brush = hex_to_brush(color)
    if title_filter:
        tfr.TitleFilter = Regex(title_filter)


def update_tabstyle(theme, tab_style):
    """Update current tab style."""
    for ts in types.TabColoringTheme.AvailableStyles:
        if ts.Name == tab_style.Name:
            theme.TabStyle = ts


def update_family_tabstyle(theme, tab_style):
    """Update current family tab style."""
    for ts in types.TabColoringTheme.AvailableStyles:
        if ts.Name == tab_style.Name:
            theme.FamilyTabStyle = ts


def get_doc_colorizer_state():
    """Get state of document colorizer."""
    return types.DocumentTabEventUtils.IsUpdatingDocumentTabs


def get_styled_slots():
    """Get list of current styling slots."""
    active_theme = types.DocumentTabEventUtils.TabColoringTheme
    if active_theme:
        return list(active_theme.StyledDocuments)


def toggle_doc_colorizer():
    """Toggle state of document colorizer."""
    if types.DocumentTabEventUtils.IsUpdatingDocumentTabs:
        types.DocumentTabEventUtils.StopGroupingDocumentTabs()
    else:
        types.DocumentTabEventUtils.StartGroupingDocumentTabs(HOST_APP.uiapp)
    return types.DocumentTabEventUtils.IsUpdatingDocumentTabs


def reset_doc_colorizer():
    """Reset document colorizer."""
    types.DocumentTabEventUtils.ResetGroupingDocumentTabs()


def init_doc_colorizer(usercfg):
    """Initialize document colorizer from settings."""
    uiapp = HOST_APP.uiapp
    if HOST_APP.is_newer_than(2018):
        current_tabcolorizer = \
            envvars.get_pyrevit_env_var(envvars.TABCOLORIZER_ENVVAR)

        new_theme = get_tabcoloring_theme(usercfg)

        # cancel out the colorizer from previous runtime version
        if current_tabcolorizer:
            # TODO: adopt the previous slots state
            # prev_theme = current_tabcolorizer.TabColoringTheme
            # if prev_theme:
            #     new_theme.InitSlots(prev_theme)
            current_tabcolorizer.StopGroupingDocumentTabs()

        # start or stop the document colorizer
        types.DocumentTabEventUtils.TabColoringTheme = new_theme
        if usercfg.colorize_docs:
            types.DocumentTabEventUtils.StartGroupingDocumentTabs(uiapp)
        else:
            types.DocumentTabEventUtils.StopGroupingDocumentTabs()

        # set the new colorizer
        envvars.set_pyrevit_env_var(
            envvars.TABCOLORIZER_ENVVAR,
            types.DocumentTabEventUtils
            )



class CustomPopupPlacement(object):
 """
 Defines custom placement parameters for a System.Windows.Controls.Primitives.Popup control.

 

 CustomPopupPlacement(point: Point,primaryAxis: PopupPrimaryAxis)
 """
 def Equals(self,o):
  """
  Equals(self: CustomPopupPlacement,o: object) -> bool

  

   Compares this structure with another System.Windows.Controls.Primitives.CustomPopupPlacement 

    structure to determine whether they are equal.

  

  

   o: The System.Windows.Controls.Primitives.CustomPopupPlacement structure to compare.

   Returns: true if the structures have the same values; otherwise,false.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: CustomPopupPlacement) -> int

  

   Gets the hash code for this structure.

   Returns: The hash code for this structure.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 @staticmethod
 def __new__(self,point,primaryAxis):
  """
  __new__(cls: type,point: Point,primaryAxis: PopupPrimaryAxis)

  __new__[CustomPopupPlacement]() -> CustomPopupPlacement
  """
  pass
 def __ne__(self,*args):
  pass
 Point=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the point that is relative to the target object where the upper-left corner of the System.Windows.Controls.Primitives.Popup control is placedl.



Get: Point(self: CustomPopupPlacement) -> Point



Set: Point(self: CustomPopupPlacement)=value

"""

 PrimaryAxis=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the direction in which to move a System.Windows.Controls.Primitives.Popup control when the System.Windows.Controls.Primitives.Popup is obscured by screen boundaries.



Get: PrimaryAxis(self: CustomPopupPlacement) -> PopupPrimaryAxis



Set: PrimaryAxis(self: CustomPopupPlacement)=value

"""





class CreateParams(object):
 """
 Encapsulates the information needed when creating a control.

 

 CreateParams()
 """
 def ToString(self):
  """
  ToString(self: CreateParams) -> str

   Returns: A string that represents the current object.
  """
  pass
 Caption=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the control's initial text.



Get: Caption(self: CreateParams) -> str



Set: Caption(self: CreateParams)=value

"""

 ClassName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the name of the Windows class to derive the control from.



Get: ClassName(self: CreateParams) -> str



Set: ClassName(self: CreateParams)=value

"""

 ClassStyle=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a bitwise combination of class style values.



Get: ClassStyle(self: CreateParams) -> int



Set: ClassStyle(self: CreateParams)=value

"""

 ExStyle=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a bitwise combination of extended window style values.



Get: ExStyle(self: CreateParams) -> int



Set: ExStyle(self: CreateParams)=value

"""

 Height=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the initial height of the control.



Get: Height(self: CreateParams) -> int



Set: Height(self: CreateParams)=value

"""

 Param=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets additional parameter information needed to create the control.



Get: Param(self: CreateParams) -> object



Set: Param(self: CreateParams)=value

"""

 Parent=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the control's parent.



Get: Parent(self: CreateParams) -> IntPtr



Set: Parent(self: CreateParams)=value

"""

 Style=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a bitwise combination of window style values.



Get: Style(self: CreateParams) -> int



Set: Style(self: CreateParams)=value

"""

 Width=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the initial width of the control.



Get: Width(self: CreateParams) -> int



Set: Width(self: CreateParams)=value

"""

 X=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the initial left position of the control.



Get: X(self: CreateParams) -> int



Set: X(self: CreateParams)=value

"""

 Y=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the top position of the initial location of the control.



Get: Y(self: CreateParams) -> int



Set: Y(self: CreateParams)=value

"""





# encoding: utf-8
# module System.Windows.Forms.ComponentModel.Com2Interop calls itself Com2Interop
# from System.Windows.Forms,Version=4.0.0.0,Culture=neutral,PublicKeyToken=b77a5c561934e089
# by generator 1.145
""" NamespaceTracker represent a CLS namespace. """
# no imports

# no functions
# classes

class Com2Variant(object):
 """
 Facilitates proper recognition of a variant type.

 

 Com2Variant()
 """

class ICom2PropertyPageDisplayService:
 """ Defines a method that shows the property page for an ActiveX control. """
 def ShowPropertyPage(self,title,component,dispid,pageGuid,parentHandle):
  """
  ShowPropertyPage(self: ICom2PropertyPageDisplayService,title: str,component: object,dispid: int,pageGuid: Guid,parentHandle: IntPtr)

   Shows a property page for the specified object.

  

   title: A string that is the title of the property page.

   component: The object for which the property page is created.

   dispid: The DispID of the property that is highlighted when the property page is created.

   pageGuid: The GUID for the property page.

   parentHandle: A IntPtr that is the handle of the parent control of the property page.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass

class IComPropertyBrowser:
 """ Allows Visual Studio to communicate internally with the System.Windows.Forms.PropertyGrid control. """
 def DropDownDone(self):
  """
  DropDownDone(self: IComPropertyBrowser)

   Closes any open drop-down controls on the System.Windows.Forms.PropertyGrid control.
  """
  pass
 def EnsurePendingChangesCommitted(self):
  """
  EnsurePendingChangesCommitted(self: IComPropertyBrowser) -> bool

  

   Commits all pending changes to the System.Windows.Forms.PropertyGrid control.

   Returns: true if the System.Windows.Forms.PropertyGrid successfully commits changes; otherwise,false.
  """
  pass
 def HandleF4(self):
  """
  HandleF4(self: IComPropertyBrowser)

   Activates the System.Windows.Forms.PropertyGrid control when the user chooses Properties for a 

    control in Design view.
  """
  pass
 def LoadState(self,key):
  """
  LoadState(self: IComPropertyBrowser,key: RegistryKey)

   Loads user states from the registry into the System.Windows.Forms.PropertyGrid control.

  

   key: The registry key that contains the user states.
  """
  pass
 def SaveState(self,key):
  """
  SaveState(self: IComPropertyBrowser,key: RegistryKey)

   Saves user states from the System.Windows.Forms.PropertyGrid control to the registry.

  

   key: The registry key that contains the user states.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 InPropertySet=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the System.Windows.Forms.PropertyGrid control is currently setting one of the properties of its selected object.



Get: InPropertySet(self: IComPropertyBrowser) -> bool



"""


 ComComponentNameChanged=None





class SelectedDatesCollection(ObservableCollection[DateTime],IList[DateTime],ICollection[DateTime],IEnumerable[DateTime],IEnumerable,IList,ICollection,IReadOnlyList[DateTime],IReadOnlyCollection[DateTime],INotifyCollectionChanged,INotifyPropertyChanged):
 """
 Represents a set of selected dates in a System.Windows.Controls.Calendar.

 

 SelectedDatesCollection(owner: Calendar)
 """
 def AddRange(self,start,end):
  """
  AddRange(self: SelectedDatesCollection,start: DateTime,end: DateTime)

   Adds all the dates in the specified range,which includes the first and last dates,to the 

    collection.

  

  

   start: The first date to add to the collection.

   end: The last date to add to the collection.
  """
  pass
 def add_PropertyChanged(self,*args):
  """ add_PropertyChanged(self: ObservableCollection[DateTime],value: PropertyChangedEventHandler) """
  pass
 def BlockReentrancy(self,*args):
  """
  BlockReentrancy(self: ObservableCollection[DateTime]) -> IDisposable

  

   Disallows reentrant attempts to change this collection.

   Returns: An System.IDisposable object that can be used to dispose of the object.
  """
  pass
 def CheckReentrancy(self,*args):
  """
  CheckReentrancy(self: ObservableCollection[DateTime])

   Checks for reentrant attempts to change this collection.
  """
  pass
 def ClearItems(self,*args):
  """ ClearItems(self: SelectedDatesCollection) """
  pass
 def InsertItem(self,*args):
  """ InsertItem(self: SelectedDatesCollection,index: int,item: DateTime) """
  pass
 def MoveItem(self,*args):
  """
  MoveItem(self: ObservableCollection[DateTime],oldIndex: int,newIndex: int)

   Moves the item at the specified index to a new location in the collection.

  

   oldIndex: The zero-based index specifying the location of the item to be moved.

   newIndex: The zero-based index specifying the new location of the item.
  """
  pass
 def OnCollectionChanged(self,*args):
  """
  OnCollectionChanged(self: ObservableCollection[DateTime],e: NotifyCollectionChangedEventArgs)

   Raises the System.Collections.ObjectModel.ObservableCollection event with the provided arguments.

  

   e: Arguments of the event being raised.
  """
  pass
 def OnPropertyChanged(self,*args):
  """
  OnPropertyChanged(self: ObservableCollection[DateTime],e: PropertyChangedEventArgs)

   Raises the System.Collections.ObjectModel.ObservableCollection event with the provided arguments.

  

   e: Arguments of the event being raised.
  """
  pass
 def RemoveItem(self,*args):
  """ RemoveItem(self: SelectedDatesCollection,index: int) """
  pass
 def remove_PropertyChanged(self,*args):
  """ remove_PropertyChanged(self: ObservableCollection[DateTime],value: PropertyChangedEventHandler) """
  pass
 def SetItem(self,*args):
  """ SetItem(self: SelectedDatesCollection,index: int,item: DateTime) """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 @staticmethod
 def __new__(self,owner):
  """ __new__(cls: type,owner: Calendar) """
  pass
 def __setitem__(self,*args):
  """ x.__setitem__(i,y) <==> x[i]= """
  pass
 Items=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a System.Collections.Generic.IList wrapper around the System.Collections.ObjectModel.Collection.



"""





class TypeLibTypeAttribute(Attribute,_Attribute):
 """
 Contains the System.Runtime.InteropServices.TYPEFLAGS that were originally imported for this type from the COM type library.

 

 TypeLibTypeAttribute(flags: TypeLibTypeFlags)

 TypeLibTypeAttribute(flags: Int16)
 """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,flags):
  """
  __new__(cls: type,flags: TypeLibTypeFlags)

  __new__(cls: type,flags: Int16)
  """
  pass
 Value=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Runtime.InteropServices.TypeLibTypeFlags value for this type.



Get: Value(self: TypeLibTypeAttribute) -> TypeLibTypeFlags



"""





class SourceSwitch(Switch):
 """
 Provides a multilevel switch to control tracing and debug output without recompiling your code.

 

 SourceSwitch(name: str)

 SourceSwitch(displayName: str,defaultSwitchValue: str)
 """
 def ShouldTrace(self,eventType):
  """
  ShouldTrace(self: SourceSwitch,eventType: TraceEventType) -> bool

  

   Determines if trace listeners should be called,based on the trace event type.

  

   eventType: One of the System.Diagnostics.TraceEventType values.

   Returns: True if the trace listeners should be called; otherwise,false.
  """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type,name: str)

  __new__(cls: type,displayName: str,defaultSwitchValue: str)
  """
  pass
 Level=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the level of the switch.



Get: Level(self: SourceSwitch) -> SourceLevels



Set: Level(self: SourceSwitch)=value

"""

 SwitchSetting=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the current setting for this switch.



"""

 Value=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the value of the switch.



"""





class CounterCreationDataCollection(CollectionBase,IList,ICollection,IEnumerable):
 """
 Provides a strongly typed collection of System.Diagnostics.CounterCreationData objects.

 

 CounterCreationDataCollection()

 CounterCreationDataCollection(value: CounterCreationDataCollection)

 CounterCreationDataCollection(value: Array[CounterCreationData])
 """
 def Add(self,value):
  """
  Add(self: CounterCreationDataCollection,value: CounterCreationData) -> int

  

   Adds an instance of the System.Diagnostics.CounterCreationData class to the collection.

  

   value: A System.Diagnostics.CounterCreationData object to append to the existing collection.

   Returns: The index of the new System.Diagnostics.CounterCreationData object.
  """
  pass
 def AddRange(self,value):
  """
  AddRange(self: CounterCreationDataCollection,value: CounterCreationDataCollection)

   Adds the specified collection of System.Diagnostics.CounterCreationData instances to the 

    collection.

  

  

   value: A collection of System.Diagnostics.CounterCreationData instances to append to the existing 

    collection.

  

  AddRange(self: CounterCreationDataCollection,value: Array[CounterCreationData])

   Adds the specified array of System.Diagnostics.CounterCreationData instances to the collection.

  

   value: An array of System.Diagnostics.CounterCreationData instances to append to the existing 

    collection.
  """
  pass
 def Contains(self,value):
  """
  Contains(self: CounterCreationDataCollection,value: CounterCreationData) -> bool

  

   Determines whether a System.Diagnostics.CounterCreationData instance exists in the collection.

  

   value: The System.Diagnostics.CounterCreationData object to find in the collection.

   Returns: true if the specified System.Diagnostics.CounterCreationData object exists in the collection; 

    otherwise,false.
  """
  pass
 def CopyTo(self,array,index):
  """
  CopyTo(self: CounterCreationDataCollection,array: Array[CounterCreationData],index: int)

   Copies the elements of the System.Diagnostics.CounterCreationData to an array,starting at the 

    specified index of the array.

  

  

   array: An array of System.Diagnostics.CounterCreationData instances to add to the collection.

   index: The location at which to add the new instances.
  """
  pass
 def IndexOf(self,value):
  """
  IndexOf(self: CounterCreationDataCollection,value: CounterCreationData) -> int

  

   Returns the index of a System.Diagnostics.CounterCreationData object in the collection.

  

   value: The System.Diagnostics.CounterCreationData object to locate in the collection.

   Returns: The zero-based index of the specified System.Diagnostics.CounterCreationData,if it is found,in 

    the collection; otherwise,-1.
  """
  pass
 def Insert(self,index,value):
  """
  Insert(self: CounterCreationDataCollection,index: int,value: CounterCreationData)

   Inserts a System.Diagnostics.CounterCreationData object into the collection,at the specified 

    index.

  

  

   index: The zero-based index of the location at which the System.Diagnostics.CounterCreationData is to 

    be inserted.

  

   value: The System.Diagnostics.CounterCreationData to insert into the collection.
  """
  pass
 def OnClear(self,*args):
  """
  OnClear(self: CollectionBase)

   Performs additional custom processes when clearing the contents of the 

    System.Collections.CollectionBase instance.
  """
  pass
 def OnClearComplete(self,*args):
  """
  OnClearComplete(self: CollectionBase)

   Performs additional custom processes after clearing the contents of the 

    System.Collections.CollectionBase instance.
  """
  pass
 def OnInsert(self,*args):
  """
  OnInsert(self: CollectionBase,index: int,value: object)

   Performs additional custom processes before inserting a new element into the 

    System.Collections.CollectionBase instance.

  

  

   index: The zero-based index at which to insert value.

   value: The new value of the element at index.
  """
  pass
 def OnInsertComplete(self,*args):
  """
  OnInsertComplete(self: CollectionBase,index: int,value: object)

   Performs additional custom processes after inserting a new element into the 

    System.Collections.CollectionBase instance.

  

  

   index: The zero-based index at which to insert value.

   value: The new value of the element at index.
  """
  pass
 def OnRemove(self,*args):
  """
  OnRemove(self: CollectionBase,index: int,value: object)

   Performs additional custom processes when removing an element from the 

    System.Collections.CollectionBase instance.

  

  

   index: The zero-based index at which value can be found.

   value: The value of the element to remove from index.
  """
  pass
 def OnRemoveComplete(self,*args):
  """
  OnRemoveComplete(self: CollectionBase,index: int,value: object)

   Performs additional custom processes after removing an element from the 

    System.Collections.CollectionBase instance.

  

  

   index: The zero-based index at which value can be found.

   value: The value of the element to remove from index.
  """
  pass
 def OnSet(self,*args):
  """
  OnSet(self: CollectionBase,index: int,oldValue: object,newValue: object)

   Performs additional custom processes before setting a value in the 

    System.Collections.CollectionBase instance.

  

  

   index: The zero-based index at which oldValue can be found.

   oldValue: The value to replace with newValue.

   newValue: The new value of the element at index.
  """
  pass
 def OnSetComplete(self,*args):
  """
  OnSetComplete(self: CollectionBase,index: int,oldValue: object,newValue: object)

   Performs additional custom processes after setting a value in the 

    System.Collections.CollectionBase instance.

  

  

   index: The zero-based index at which oldValue can be found.

   oldValue: The value to replace with newValue.

   newValue: The new value of the element at index.
  """
  pass
 def OnValidate(self,*args):
  """
  OnValidate(self: CounterCreationDataCollection,value: object)

   Checks the specified object to determine whether it is a valid 

    System.Diagnostics.CounterCreationData type.

  

  

   value: The object that will be validated.
  """
  pass
 def Remove(self,value):
  """
  Remove(self: CounterCreationDataCollection,value: CounterCreationData)

   Removes a System.Diagnostics.CounterCreationData object from the collection.

  

   value: The System.Diagnostics.CounterCreationData to remove from the collection.
  """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+y """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 @staticmethod
 def __new__(self,value=None):
  """
  __new__(cls: type)

  __new__(cls: type,value: CounterCreationDataCollection)

  __new__(cls: type,value: Array[CounterCreationData])
  """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __setitem__(self,*args):
  """ x.__setitem__(i,y) <==> x[i]= """
  pass
 InnerList=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets an System.Collections.ArrayList containing the list of elements in the System.Collections.CollectionBase instance.



"""

 List=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets an System.Collections.IList containing the list of elements in the System.Collections.CollectionBase instance.



"""





class InstanceData(object):
 """
 Holds instance data associated with a performance counter sample.

 

 InstanceData(instanceName: str,sample: CounterSample)
 """
 @staticmethod
 def __new__(self,instanceName,sample):
  """ __new__(cls: type,instanceName: str,sample: CounterSample) """
  pass
 InstanceName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the instance name associated with this instance data.



Get: InstanceName(self: InstanceData) -> str



"""

 RawValue=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the raw data value associated with the performance counter sample.



Get: RawValue(self: InstanceData) -> Int64



"""

 Sample=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the performance counter sample that generated this data.



Get: Sample(self: InstanceData) -> CounterSample



"""





class TraceOptions(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies trace data options to be written to the trace output.

 

 enum (flags) TraceOptions,values: Callstack (32),DateTime (2),LogicalOperationStack (1),None (0),ProcessId (8),ThreadId (16),Timestamp (4)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Callstack=None
 DateTime=None
 LogicalOperationStack=None
 None=None
 ProcessId=None
 ThreadId=None
 Timestamp=None
 value__=None




class DispatchWrapper(object):
 """
 Wraps objects the marshaler should marshal as a VT_DISPATCH.

 

 DispatchWrapper(obj: object)
 """
 @staticmethod
 def __new__(self,obj):
  """ __new__(cls: type,obj: object) """
  pass
 WrappedObject=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the object wrapped by the System.Runtime.InteropServices.DispatchWrapper.



Get: WrappedObject(self: DispatchWrapper) -> object



"""





class TextWriter(MarshalByRefObject,IDisposable):
 """ Represents a writer that can write a sequential series of characters. This class is abstract. """
 def Close(self):
  """
  Close(self: TextWriter)

   Closes the current writer and releases any system resources associated with the writer.
  """
  pass
 def Dispose(self):
  """
  Dispose(self: TextWriter)

   Releases all resources used by the System.IO.TextWriter object.
  """
  pass
 def Flush(self):
  """
  Flush(self: TextWriter)

   Clears all buffers for the current writer and causes any buffered data to be written to the 

    underlying device.
  """
  pass
 def FlushAsync(self):
  """ FlushAsync(self: TextWriter) -> Task """
  pass
 def MemberwiseClone(self,*args):
  """
  MemberwiseClone(self: MarshalByRefObject,cloneIdentity: bool) -> MarshalByRefObject

  

   Creates a shallow copy of the current System.MarshalByRefObject object.

  

   cloneIdentity: false to delete the current System.MarshalByRefObject object's identity,which will cause the 

    object to be assigned a new identity when it is marshaled across a remoting boundary. A value of 

    false is usually appropriate. true to copy the current System.MarshalByRefObject object's 

    identity to its clone,which will cause remoting client calls to be routed to the remote server 

    object.

  

   Returns: A shallow copy of the current System.MarshalByRefObject object.

  MemberwiseClone(self: object) -> object

  

   Creates a shallow copy of the current System.Object.

   Returns: A shallow copy of the current System.Object.
  """
  pass
 @staticmethod
 def Synchronized(writer):
  """
  Synchronized(writer: TextWriter) -> TextWriter

  

   Creates a thread-safe wrapper around the specified TextWriter.

  

   writer: The TextWriter to synchronize.

   Returns: A thread-safe wrapper.
  """
  pass
 def Write(self,*__args):
  """
  Write(self: TextWriter,value: str)

   Writes a string to the text stream.

  

   value: The string to write.

  Write(self: TextWriter,value: object)

   Writes the text representation of an object to the text stream by calling ToString on that 

    object.

  

  

   value: The object to write.

  Write(self: TextWriter,value: float)

   Writes the text representation of an 8-byte floating-point value to the text stream.

  

   value: The 8-byte floating-point value to write.

  Write(self: TextWriter,value: Decimal)

   Writes the text representation of a decimal value to the text stream.

  

   value: The decimal value to write.

  Write(self: TextWriter,format: str,arg0: object,arg1: object,arg2: object)

   Writes out a formatted string,using the same semantics as 

    System.String.Format(System.String,System.Object).

  

  

   format: The formatting string.

   arg0: An object to write into the formatted string.

   arg1: An object to write into the formatted string.

   arg2: An object to write into the formatted string.

  Write(self: TextWriter,format: str,*arg: Array[object])

   Writes out a formatted string,using the same semantics as 

    System.String.Format(System.String,System.Object).

  

  

   format: The formatting string.

   arg: The object array to write into the formatted string.

  Write(self: TextWriter,format: str,arg0: object)

   Writes out a formatted string,using the same semantics as 

    System.String.Format(System.String,System.Object).

  

  

   format: The formatting string.

   arg0: An object to write into the formatted string.

  Write(self: TextWriter,format: str,arg0: object,arg1: object)

   Writes out a formatted string,using the same semantics as 

    System.String.Format(System.String,System.Object).

  

  

   format: The formatting string.

   arg0: An object to write into the formatted string.

   arg1: An object to write into the formatted string.

  Write(self: TextWriter,value: Single)

   Writes the text representation of a 4-byte floating-point value to the text stream.

  

   value: The 4-byte floating-point value to write.

  Write(self: TextWriter,buffer: Array[Char],index: int,count: int)

   Writes a subarray of characters to the text stream.

  

   buffer: The character array to write data from.

   index: Starting index in the buffer.

   count: The number of characters to write.

  Write(self: TextWriter,value: bool)

   Writes the text representation of a Boolean value to the text stream.

  

   value: The Boolean to write.

  Write(self: TextWriter,value: Char)

   Writes a character to the text stream.

  

   value: The character to write to the text stream.

  Write(self: TextWriter,buffer: Array[Char])

   Writes a character array to the text stream.

  

   buffer: The character array to write to the text stream.

  Write(self: TextWriter,value: Int64)

   Writes the text representation of an 8-byte signed integer to the text stream.

  

   value: The 8-byte signed integer to write.

  Write(self: TextWriter,value: UInt64)

   Writes the text representation of an 8-byte unsigned integer to the text stream.

  

   value: The 8-byte unsigned integer to write.

  Write(self: TextWriter,value: int)

   Writes the text representation of a 4-byte signed integer to the text stream.

  

   value: The 4-byte signed integer to write.

  Write(self: TextWriter,value: UInt32)

   Writes the text representation of a 4-byte unsigned integer to the text stream.

  

   value: The 4-byte unsigned integer to write.
  """
  pass
 def WriteAsync(self,*__args):
  """
  WriteAsync(self: TextWriter,buffer: Array[Char]) -> Task

  WriteAsync(self: TextWriter,buffer: Array[Char],index: int,count: int) -> Task

  WriteAsync(self: TextWriter,value: Char) -> Task

  WriteAsync(self: TextWriter,value: str) -> Task
  """
  pass
 def WriteLine(self,*__args):
  """
  WriteLine(self: TextWriter,value: Decimal)

   Writes the text representation of a decimal value followed by a line terminator to the text 

    stream.

  

  

   value: The decimal value to write.

  WriteLine(self: TextWriter,value: str)

   Writes a string followed by a line terminator to the text stream.

  

   value: The string to write. If value is null,only the line termination characters are written.

  WriteLine(self: TextWriter,value: Single)

   Writes the text representation of a 4-byte floating-point value followed by a line terminator to 

    the text stream.

  

  

   value: The 4-byte floating-point value to write.

  WriteLine(self: TextWriter,value: float)

   Writes the text representation of a 8-byte floating-point value followed by a line terminator to 

    the text stream.

  

  

   value: The 8-byte floating-point value to write.

  WriteLine(self: TextWriter,value: object)

   Writes the text representation of an object by calling ToString on this object,followed by a 

    line terminator to the text stream.

  

  

   value: The object to write. If value is null,only the line termination characters are written.

  WriteLine(self: TextWriter,format: str,arg0: object,arg1: object,arg2: object)

   Writes out a formatted string and a new line,using the same semantics as 

    System.String.Format(System.String,System.Object).

  

  

   format: The formatting string.

   arg0: The object to write into the format string.

   arg1: The object to write into the format string.

   arg2: The object to write into the format string.

  WriteLine(self: TextWriter,format: str,*arg: Array[object])

   Writes out a formatted string and a new line,using the same semantics as 

    System.String.Format(System.String,System.Object).

  

  

   format: The formatting string.

   arg: The object array to write into format string.

  WriteLine(self: TextWriter,format: str,arg0: object)

   Writes out a formatted string and a new line,using the same semantics as 

    System.String.Format(System.String,System.Object).

  

  

   format: The formatted string.

   arg0: The object to write into the formatted string.

  WriteLine(self: TextWriter,format: str,arg0: object,arg1: object)

   Writes out a formatted string and a new line,using the same semantics as 

    System.String.Format(System.String,System.Object).

  

  

   format: The formatting string.

   arg0: The object to write into the format string.

   arg1: The object to write into the format string.

  WriteLine(self: TextWriter,buffer: Array[Char])

   Writes an array of characters followed by a line terminator to the text stream.

  

   buffer: The character array from which data is read.

  WriteLine(self: TextWriter,buffer: Array[Char],index: int,count: int)

   Writes a subarray of characters followed by a line terminator to the text stream.

  

   buffer: The character array from which data is read.

   index: The index into buffer at which to begin reading.

   count: The maximum number of characters to write.

  WriteLine(self: TextWriter)

   Writes a line terminator to the text stream.

  WriteLine(self: TextWriter,value: Char)

   Writes a character followed by a line terminator to the text stream.

  

   value: The character to write to the text stream.

  WriteLine(self: TextWriter,value: bool)

   Writes the text representation of a Boolean followed by a line terminator to the text stream.

  

   value: The Boolean to write.

  WriteLine(self: TextWriter,value: Int64)

   Writes the text representation of an 8-byte signed integer followed by a line terminator to the 

    text stream.

  

  

   value: The 8-byte signed integer to write.

  WriteLine(self: TextWriter,value: UInt64)

   Writes the text representation of an 8-byte unsigned integer followed by a line terminator to 

    the text stream.

  

  

   value: The 8-byte unsigned integer to write.

  WriteLine(self: TextWriter,value: int)

   Writes the text representation of a 4-byte signed integer followed by a line terminator to the 

    text stream.

  

  

   value: The 4-byte signed integer to write.

  WriteLine(self: TextWriter,value: UInt32)

   Writes the text representation of a 4-byte unsigned integer followed by a line terminator to the 

    text stream.

  

  

   value: The 4-byte unsigned integer to write.
  """
  pass
 def WriteLineAsync(self,*__args):
  """
  WriteLineAsync(self: TextWriter,buffer: Array[Char],index: int,count: int) -> Task

  WriteLineAsync(self: TextWriter) -> Task

  WriteLineAsync(self: TextWriter,buffer: Array[Char]) -> Task

  WriteLineAsync(self: TextWriter,value: Char) -> Task

  WriteLineAsync(self: TextWriter,value: str) -> Task
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,*args): #cannot find CLR constructor
  """
  __new__(cls: type)

  __new__(cls: type,formatProvider: IFormatProvider)
  """
  pass
 def __reduce_ex__(self,*args):
  pass
 Encoding=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """When overridden in a derived class,returns the System.Text.Encoding in which the output is written.



Get: Encoding(self: TextWriter) -> Encoding



"""

 FormatProvider=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets an object that controls formatting.



Get: FormatProvider(self: TextWriter) -> IFormatProvider



"""

 NewLine=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the line terminator string used by the current TextWriter.



Get: NewLine(self: TextWriter) -> str



Set: NewLine(self: TextWriter)=value

"""


 CoreNewLine=None
 Null=None




class DrawListViewSubItemEventArgs(EventArgs):
 """
 Provides data for the System.Windows.Forms.ListView.DrawSubItem event.

 

 DrawListViewSubItemEventArgs(graphics: Graphics,bounds: Rectangle,item: ListViewItem,subItem: ListViewSubItem,itemIndex: int,columnIndex: int,header: ColumnHeader,itemState: ListViewItemStates)
 """
 def DrawBackground(self):
  """
  DrawBackground(self: DrawListViewSubItemEventArgs)

   Draws the background of the System.Windows.Forms.ListViewItem.ListViewSubItem using its current 

    background color.
  """
  pass
 def DrawFocusRectangle(self,bounds):
  """
  DrawFocusRectangle(self: DrawListViewSubItemEventArgs,bounds: Rectangle)

   Draws a focus rectangle for the System.Windows.Forms.ListViewItem.ListViewSubItem if the parent 

    System.Windows.Forms.ListViewItem has focus.

  

  

   bounds: The area within which to draw the focus rectangle.
  """
  pass
 def DrawText(self,flags=None):
  """
  DrawText(self: DrawListViewSubItemEventArgs,flags: TextFormatFlags)

   Draws the text of the System.Windows.Forms.ListViewItem.ListViewSubItem using its current 

    foreground color and formatting it with the specified System.Windows.Forms.TextFormatFlags 

    values.

  

  

   flags: A bitwise combination of System.Windows.Forms.TextFormatFlags values.

  DrawText(self: DrawListViewSubItemEventArgs)

   Draws the text of the System.Windows.Forms.ListViewItem.ListViewSubItem using its current 

    foreground color.
  """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y] """
  pass
 @staticmethod
 def __new__(self,graphics,bounds,item,subItem,itemIndex,columnIndex,header,itemState):
  """ __new__(cls: type,graphics: Graphics,bounds: Rectangle,item: ListViewItem,subItem: ListViewSubItem,itemIndex: int,columnIndex: int,header: ColumnHeader,itemState: ListViewItemStates) """
  pass
 Bounds=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the size and location of the System.Windows.Forms.ListViewItem.ListViewSubItem to draw.



Get: Bounds(self: DrawListViewSubItemEventArgs) -> Rectangle



"""

 ColumnIndex=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the index of the System.Windows.Forms.ListView column in which the System.Windows.Forms.ListViewItem.ListViewSubItem is displayed.



Get: ColumnIndex(self: DrawListViewSubItemEventArgs) -> int



"""

 DrawDefault=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the System.Windows.Forms.ListViewItem.ListViewSubItem should be drawn by the operating system instead of owner-drawn.



Get: DrawDefault(self: DrawListViewSubItemEventArgs) -> bool



Set: DrawDefault(self: DrawListViewSubItemEventArgs)=value

"""

 Graphics=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Drawing.Graphics used to draw the System.Windows.Forms.ListViewItem.ListViewSubItem.



Get: Graphics(self: DrawListViewSubItemEventArgs) -> Graphics



"""

 Header=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the header of the System.Windows.Forms.ListView column in which the System.Windows.Forms.ListViewItem.ListViewSubItem is displayed.



Get: Header(self: DrawListViewSubItemEventArgs) -> ColumnHeader



"""

 Item=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the parent System.Windows.Forms.ListViewItem of the System.Windows.Forms.ListViewItem.ListViewSubItem to draw.



Get: Item(self: DrawListViewSubItemEventArgs) -> ListViewItem



"""

 ItemIndex=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the index of the parent System.Windows.Forms.ListViewItem of the System.Windows.Forms.ListViewItem.ListViewSubItem to draw.



Get: ItemIndex(self: DrawListViewSubItemEventArgs) -> int



"""

 ItemState=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the current state of the parent System.Windows.Forms.ListViewItem of the System.Windows.Forms.ListViewItem.ListViewSubItem to draw.



Get: ItemState(self: DrawListViewSubItemEventArgs) -> ListViewItemStates



"""

 SubItem=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Windows.Forms.ListViewItem.ListViewSubItem to draw.



Get: SubItem(self: DrawListViewSubItemEventArgs) -> ListViewSubItem



"""





"""Table of Contents Extension for Python-Markdown.

See <https://pythonhosted.org/Markdown/extensions/toc.html>
for documentation.

Original code Copyright 2008 [Jack Miller](http://codezen.org)

All changes Copyright 2008-2014 The Python Markdown Project

License: [BSD](http://www.opensource.org/licenses/bsd-license.php)
"""

from __future__ import absolute_import
from __future__ import unicode_literals
from . import Extension
from ..treeprocessors import Treeprocessor
from ..util import etree, parseBoolValue, AMP_SUBSTITUTE, HTML_PLACEHOLDER_RE, string_type
import re
import unicodedata


def slugify(value, separator):
    """Slugify a string, to make it URL friendly."""
    value = unicodedata.normalize('NFKD', value).encode('ascii', 'ignore')
    value = re.sub(r'[^\w\s-]', '', value.decode('ascii')).strip().lower()
    return re.sub(r'[%s\s]+' % separator, separator, value)


IDCOUNT_RE = re.compile(r'^(.*)_([0-9]+)$')


def unique(id, ids):
    """Ensure id is unique in set of ids. Append '_1', '_2'... if not."""
    while id in ids or not id:
        m = IDCOUNT_RE.match(id)
        if m:
            id = '%s_%d' % (m.group(1), int(m.group(2))+1)
        else:
            id = '%s_%d' % (id, 1)
    ids.add(id)
    return id


def stashedHTML2text(text, md):
    """Extract raw HTML from stash, reduce to plain text and swap with placeholder."""
    def _html_sub(m):
        """Substitute raw html with plain text."""
        try:
            raw, safe = md.htmlStash.rawHtmlBlocks[int(m.group(1))]
        except (IndexError, TypeError):  # pragma: no cover
            return m.group(0)
        if md.safeMode and not safe:  # pragma: no cover
            return ''
        # Strip out tags and entities - leaveing text
        return re.sub(r'(<[^>]+>)|(&[\#a-zA-Z0-9]+;)', '', raw)

    return HTML_PLACEHOLDER_RE.sub(_html_sub, text)


def nest_toc_tokens(toc_list):
    """Given an unsorted list with errors and skips, return a nested one.

    Examples:
        [{'level': 1}, {'level': 2}]
        =>
        [{'level': 1, 'children': [{'level': 2, 'children': []}]}].

        A wrong list is also converted:
        [{'level': 2}, {'level': 1}]
        =>
        [{'level': 2, 'children': []}, {'level': 1, 'children': []}]
    """
    ordered_list = []
    if len(toc_list):
        # Initialize everything by processing the first entry
        last = toc_list.pop(0)
        last['children'] = []
        levels = [last['level']]
        ordered_list.append(last)
        parents = []

        # Walk the rest nesting the entries properly
        while toc_list:
            t = toc_list.pop(0)
            current_level = t['level']
            t['children'] = []

            # Reduce depth if current level < last item's level
            if current_level < levels[-1]:
                # Pop last level since we know we are less than it
                levels.pop()

                # Pop parents and levels we are less than or equal to
                to_pop = 0
                for p in reversed(parents):
                    if current_level <= p['level']:
                        to_pop += 1
                    else:  # pragma: no cover
                        break
                if to_pop:
                    levels = levels[:-to_pop]
                    parents = parents[:-to_pop]

                # Note current level as last
                levels.append(current_level)

            # Level is the same, so append to
            # the current parent (if available)
            if current_level == levels[-1]:
                (parents[-1]['children'] if parents
                 else ordered_list).append(t)

            # Current level is > last item's level,
            # So make last item a parent and append current as child
            else:
                last['children'].append(t)
                parents.append(last)
                levels.append(current_level)
            last = t

    return ordered_list


class TocTreeprocessor(Treeprocessor):
    """TOC Tree processor."""
    def __init__(self, md, config):
        super(TocTreeprocessor, self).__init__(md)

        self.marker = config["marker"]
        self.title = config["title"]
        self.base_level = int(config["baselevel"]) - 1
        self.slugify = config["slugify"]
        self.sep = config["separator"]
        self.use_anchors = parseBoolValue(config["anchorlink"])
        self.use_permalinks = parseBoolValue(config["permalink"], False)
        if self.use_permalinks is None:
            self.use_permalinks = config["permalink"]

        self.header_rgx = re.compile("[Hh][123456]")

    def iterparent(self, root):
        """Iterator wrapper to get parent and child all at once."""
        for parent in root.iter():
            for child in parent:
                yield parent, child

    def replace_marker(self, root, elem):
        """Replace marker with elem."""
        for (p, c) in self.iterparent(root):
            text = ''.join(c.itertext()).strip()
            if not text:
                continue

            # To keep the output from screwing up the
            # validation by putting a <div> inside of a <p>
            # we actually replace the <p> in its entirety.
            # We do not allow the marker inside a header as that
            # would causes an enless loop of placing a new TOC
            # inside previously generated TOC.
            if c.text and c.text.strip() == self.marker and \
               not self.header_rgx.match(c.tag) and c.tag not in ['pre', 'code']:
                for i in range(len(p)):
                    if p[i] == c:
                        p[i] = elem
                        break

    def set_level(self, elem):
        """Adjust header level according to base level."""
        level = int(elem.tag[-1]) + self.base_level
        if level > 6:
            level = 6
        elem.tag = 'h%d' % level

    def add_anchor(self, c, elem_id):  # @ReservedAssignment
        anchor = etree.Element("a")
        anchor.text = c.text
        anchor.attrib["href"] = "#" + elem_id
        anchor.attrib["class"] = "toclink"
        c.text = ""
        for elem in c:
            anchor.append(elem)
        while c:
            c.remove(c[0])
        c.append(anchor)

    def add_permalink(self, c, elem_id):
        permalink = etree.Element("a")
        permalink.text = ("%spara;" % AMP_SUBSTITUTE
                          if self.use_permalinks is True
                          else self.use_permalinks)
        permalink.attrib["href"] = "#" + elem_id
        permalink.attrib["class"] = "headerlink"
        permalink.attrib["title"] = "Permanent link"
        c.append(permalink)

    def build_toc_div(self, toc_list):
        """Return a string div given a toc list."""
        div = etree.Element("div")
        div.attrib["class"] = "toc"

        # Add title to the div
        if self.title:
            header = etree.SubElement(div, "span")
            header.attrib["class"] = "toctitle"
            header.text = self.title

        def build_etree_ul(toc_list, parent):
            ul = etree.SubElement(parent, "ul")
            for item in toc_list:
                # List item link, to be inserted into the toc div
                li = etree.SubElement(ul, "li")
                link = etree.SubElement(li, "a")
                link.text = item.get('name', '')
                link.attrib["href"] = '#' + item.get('id', '')
                if item['children']:
                    build_etree_ul(item['children'], li)
            return ul

        build_etree_ul(toc_list, div)
        prettify = self.markdown.treeprocessors.get('prettify')
        if prettify:
            prettify.run(div)
        return div

    def run(self, doc):
        # Get a list of id attributes
        used_ids = set()
        for el in doc.iter():
            if "id" in el.attrib:
                used_ids.add(el.attrib["id"])

        toc_tokens = []
        for el in doc.iter():
            if isinstance(el.tag, string_type) and self.header_rgx.match(el.tag):
                self.set_level(el)
                text = ''.join(el.itertext()).strip()

                # Do not override pre-existing ids
                if "id" not in el.attrib:
                    innertext = stashedHTML2text(text, self.markdown)
                    el.attrib["id"] = unique(self.slugify(innertext, self.sep), used_ids)

                toc_tokens.append({
                    'level': int(el.tag[-1]),
                    'id': el.attrib["id"],
                    'name': text
                })

                if self.use_anchors:
                    self.add_anchor(el, el.attrib["id"])
                if self.use_permalinks:
                    self.add_permalink(el, el.attrib["id"])

        div = self.build_toc_div(nest_toc_tokens(toc_tokens))
        if self.marker:
            self.replace_marker(doc, div)

        # serialize and attach to markdown instance.
        toc = self.markdown.serializer(div)
        for pp in self.markdown.postprocessors.values():
            toc = pp.run(toc)
        self.markdown.toc = toc


class TocExtension(Extension):
    """TOC Markdown extension."""

    TreeProcessorClass = TocTreeprocessor

    def __init__(self, *args, **kwargs):
        self.config = {
            "marker": ['[TOC]',
                       'Text to find and replace with Table of Contents - '
                       'Set to an empty string to disable. Defaults to "[TOC]"'],
            "title": ["",
                      "Title to insert into TOC <div> - "
                      "Defaults to an empty string"],
            "anchorlink": [False,
                           "True if header should be a self link - "
                           "Defaults to False"],
            "permalink": [0,
                          "True or link text if a Sphinx-style permalink should "
                          "be added - Defaults to False"],
            "baselevel": ['1', 'Base level for headers.'],
            "slugify": [slugify,
                        "Function to generate anchors based on header text - "
                        "Defaults to the headerid ext's slugify function."],
            'separator': ['-', 'Word separator. Defaults to "-".']
        }

        super(TocExtension, self).__init__(*args, **kwargs)

    def extendMarkdown(self, md, md_globals):
        md.registerExtension(self)
        self.md = md
        self.reset()
        tocext = self.TreeProcessorClass(md, self.getConfigs())
        # Headerid ext is set to '>prettify'. With this set to '_end',
        # it should always come after headerid ext (and honor ids assinged
        # by the header id extension) if both are used. Same goes for
        # attr_list extension. This must come last because we don't want
        # to redefine ids after toc is created. But we do want toc prettified.
        md.treeprocessors.add("toc", tocext, "_end")

    def reset(self):
        self.md.toc = ''


def makeExtension(*args, **kwargs):
    return TocExtension(*args, **kwargs)



from typing import Tuple, Set, Iterable, List


class AddInIdAttribute:
    def __init__(self, addInIdStr: str): ...
    @property
    def Value(self) -> ValueType: ...


class IEntryPoint:
    def Initialize(self, obj: Object, addinFolder: str) -> None: ...
    def FinishInitialization(self) -> None: ...
    def OnShutdown(self) -> None: ...
    @property
    def AddinFolder(self) -> str: ...


class ApplicationEntryPoint(Application):
    def __init__(self): ...
    def Initialize(self, obj: Object, addinFolder: str) -> None: ...
    def FinishInitializationEO(self) -> None: ...
    def OnShutdownEO(self) -> None: ...
    @property
    def AddinFolder(self) -> str: ...


class DocumentEntryPoint(Document):
    def __init__(self): ...
    def Initialize(self, obj: Object, addinFolder: str) -> None: ...
    def FinishInitializationEO(self) -> None: ...
    def OnShutdownEO(self) -> None: ...
    @property
    def AddinFolder(self) -> str: ...


class VendorIdAttribute:
    def __init__(self, vendorIdStr: str): ...
    @property
    def Value(self) -> str: ...



class ImmutableObjectAttribute(Attribute,_Attribute):
 """
 Specifies that an object has no subproperties capable of being edited. This class cannot be inherited.

 

 ImmutableObjectAttribute(immutable: bool)
 """
 def Equals(self,obj):
  """
  Equals(self: ImmutableObjectAttribute,obj: object) -> bool

  

   obj: An System.Object to compare with this instance or null.

   Returns: true if obj equals the type and value of this instance; otherwise,false.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: ImmutableObjectAttribute) -> int

  

   Returns the hash code for this instance.

   Returns: A hash code for the current System.ComponentModel.ImmutableObjectAttribute.
  """
  pass
 def IsDefaultAttribute(self):
  """
  IsDefaultAttribute(self: ImmutableObjectAttribute) -> bool

  

   Indicates whether the value of this instance is the default value.

   Returns: true if this instance is the default attribute for the class; otherwise,false.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,immutable):
  """ __new__(cls: type,immutable: bool) """
  pass
 def __ne__(self,*args):
  pass
 Immutable=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets whether the object is immutable.



Get: Immutable(self: ImmutableObjectAttribute) -> bool



"""


 Default=None
 No=None
 Yes=None




class RadioButtonRenderer(object):
 """ Provides methods used to render an option button control (also known as a radio button) with or without visual styles. This class cannot be inherited. """
 @staticmethod
 def DrawParentBackground(g,bounds,childControl):
  """
  DrawParentBackground(g: Graphics,bounds: Rectangle,childControl: Control)

   Draws the background of a control's parent in the specified area.

  

   g: The System.Drawing.Graphics used to draw the background of the parent of childControl.

   bounds: The System.Drawing.Rectangle in which to draw the parent control's background. This rectangle 

    

   childControl: The control whose parent's background will be drawn.
  """
  pass
 @staticmethod
 def DrawRadioButton(g,glyphLocation,*__args):
  """
  DrawRadioButton(g: Graphics,glyphLocation: Point,textBounds: Rectangle,radioButtonText: str,font: Font,image: Image,imageBounds: Rectangle,focused: bool,state: RadioButtonState)

   Draws an option button control (also known as a radio button) in the specified state and 

    location,with the specified text and image,and with an optional focus rectangle.

  

  

   g: The System.Drawing.Graphics used to draw the option button.

   glyphLocation: The System.Drawing.Point to draw the option button glyph at.

   textBounds: The System.Drawing.Rectangle to draw radioButtonText in.

   radioButtonText: The System.String to draw with the option button.

   font: The System.Drawing.Font to apply to radioButtonText.

   image: The System.Drawing.Image to draw with the option button.

   imageBounds: The System.Drawing.Rectangle to draw image in.

   focused: true to draw a focus rectangle; otherwise,false.

   state: One of the System.Windows.Forms.VisualStyles.RadioButtonState values that specifies the visual 

    state of the option button.

  

  DrawRadioButton(g: Graphics,glyphLocation: Point,textBounds: Rectangle,radioButtonText: str,font: Font,flags: TextFormatFlags,image: Image,imageBounds: Rectangle,focused: bool,state: RadioButtonState)

   Draws an option button control (also known as a radio button) in the specified state and 

    location; with the specified text,text formatting,and image; and with an optional focus 

    rectangle.

  

  

   g: The System.Drawing.Graphics used to draw the option button.

   glyphLocation: The System.Drawing.Point to draw the option button glyph at.

   textBounds: The System.Drawing.Rectangle to draw radioButtonText in.

   radioButtonText: The System.String to draw with the option button.

   font: The System.Drawing.Font to apply to radioButtonText.

   flags: A bitwise combination of the System.Windows.Forms.TextFormatFlags values.

   image: The System.Drawing.Image to draw with the option button.

   imageBounds: The System.Drawing.Rectangle to draw image in.

   focused: true to draw a focus rectangle; otherwise,false.

   state: One of the System.Windows.Forms.VisualStyles.RadioButtonState values that specifies the visual 

    state of the option button.

  

  DrawRadioButton(g: Graphics,glyphLocation: Point,textBounds: Rectangle,radioButtonText: str,font: Font,flags: TextFormatFlags,focused: bool,state: RadioButtonState)

   Draws an option button control (also known as a radio button) in the specified state and 

    location,with the specified text and text formatting,and with an optional focus rectangle.

  

  

   g: The System.Drawing.Graphics used to draw the option button.

   glyphLocation: The System.Drawing.Point to draw the option button glyph at.

   textBounds: The System.Drawing.Rectangle to draw radioButtonText in.

   radioButtonText: The System.String to draw with the option button.

   font: The System.Drawing.Font to apply to radioButtonText.

   flags: A bitwise combination of the System.Windows.Forms.TextFormatFlags values.

   focused: true to draw a focus rectangle; otherwise,false.

   state: One of the System.Windows.Forms.VisualStyles.RadioButtonState values that specifies the visual 

    state of the option button.

  

  DrawRadioButton(g: Graphics,glyphLocation: Point,state: RadioButtonState)

   Draws an option button control (also known as a radio button) in the specified state and 

    location.

  

  

   g: The System.Drawing.Graphics used to draw the option button.

   glyphLocation: The System.Drawing.Point to draw the option button glyph at.

   state: One of the System.Windows.Forms.VisualStyles.RadioButtonState values that specifies the visual 

    state of the option button.

  

  DrawRadioButton(g: Graphics,glyphLocation: Point,textBounds: Rectangle,radioButtonText: str,font: Font,focused: bool,state: RadioButtonState)

   Draws an option button control (also known as a radio button) in the specified state and 

    location,with the specified text,and with an optional focus rectangle.

  

  

   g: The System.Drawing.Graphics used to draw the option button.

   glyphLocation: The System.Drawing.Point to draw the option button glyph at.

   textBounds: The System.Drawing.Rectangle to draw radioButtonText in.

   radioButtonText: The System.String to draw with the option button.

   font: The System.Drawing.Font to apply to radioButtonText.

   focused: true to draw a focus rectangle; otherwise,false.

   state: One of the System.Windows.Forms.VisualStyles.RadioButtonState values that specifies the visual 

    state of the option button.
  """
  pass
 @staticmethod
 def GetGlyphSize(g,state):
  """
  GetGlyphSize(g: Graphics,state: RadioButtonState) -> Size

  

   Returns the size,in pixels,of the option button (also known as a radio button) glyph.

  

   g: The System.Drawing.Graphics used to draw the option button.

   state: One of the System.Windows.Forms.VisualStyles.RadioButtonState values that specifies the visual 

    state of the option button.

  

   Returns: A System.Drawing.Size that represents the size,in pixels,of the option button glyph.
  """
  pass
 @staticmethod
 def IsBackgroundPartiallyTransparent(state):
  """
  IsBackgroundPartiallyTransparent(state: RadioButtonState) -> bool

  

   Indicates whether the background of the option button (also known as a radio button) has 

    semitransparent or alpha-blended pieces.

  

  

   state: One of the System.Windows.Forms.VisualStyles.RadioButtonState values that specifies the visual 

    state of the option button.

  

   Returns: true if the background of the option button has semitransparent or alpha-blended pieces; 

    otherwise,false.
  """
  pass
 RenderMatchingApplicationState=True




class AceFlags(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the inheritance and auditing behavior of an access control entry (ACE).

 

 enum (flags) AceFlags,values: AuditFlags (192),ContainerInherit (2),FailedAccess (128),InheritanceFlags (15),Inherited (16),InheritOnly (8),None (0),NoPropagateInherit (4),ObjectInherit (1),SuccessfulAccess (64)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 AuditFlags=None
 ContainerInherit=None
 FailedAccess=None
 InheritanceFlags=None
 Inherited=None
 InheritOnly=None
 None=None
 NoPropagateInherit=None
 ObjectInherit=None
 SuccessfulAccess=None
 value__=None

